***************************************************************.
* SPSS program for computing household consumption to be used  .
* for poverty analysis (Consumption <> expenditure);           .
* The program also computes regional price deflators based on  .
* Paachse and Laspeyres methods;                               .
* The computations follow recommendations by Deaton and Zaidi; .
* See "Guidelines for Constructing Consumption Aggregates for  .
* Welfare Analysis"                                            .
***************************************************************.

* Consumption includes all food expenditure.
* Consumption does not include durables.
* Consumption does not include remittances.
* Consumption does not include consultation and hospitalizations.
* Consumption does not include taxes.
* Consumption does not include lumpy expenditures such as dowries.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Food expenditure by'+
 ' item and source.SAV'.
ADD FILES /FILE=*
 /FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Non food expenditure'+
 ' by item and source.SAV'.
EXECUTE.
SORT CASES BY
  stratum (A) dzongkha (A) town (A) block (A) houseno (A) itemcode (A) source (A) .

SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp4.sav'
  /COMPRESSED.

* Remove non-consumption components.

COMPUTE dropit = 0.
EXECUTE.
IF (itemcode=2415) dropit = 1 .
IF (itemcode>=2512 and itemcode <=2519) dropit = 1 .
IF (itemcode>=2512 and itemcode <=2616) dropit = 1 .
IF (itemcode=2618) dropit = 1 .
IF (itemcode=2619) dropit = 1 .
IF (itemcode=5011) dropit = 1 .
IF (category=27) dropit = 1 .
IF (category=81) dropit = 1 .
EXECUTE.
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp4.sav'
  /COMPRESSED.

* Add consumption of education .
* For children attending school in Bhutan, we include the value of the 
* service provided by the Government at estimated provision cost.
* For grades 0 to 6: 5,751 per year.
* For grades 7 and 8: 5,975 per year.
* For grades 9 to 12: 8,701 per year.
* For grades 13 to 15: 71,150 per year.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Block2_edited.sav'.
FILTER OFF.
USE ALL.
SELECT IF(b22_q9=1.).
EXECUTE .
IF (b22_q10>= 0  and b22_q10<=6)  cost_edu =  5751 .
IF (b22_q10>= 7  and b22_q10<=8)  cost_edu =  5975 .
IF (b22_q10>= 9  and b22_q10<=12) cost_edu =  8701 .
IF (b22_q10>= 13 and b22_q10<=15) cost_edu = 71150 .
EXECUTE .
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR.SAV'
  /BREAK=stratum dzongkha town block houseno
  /exp_annu = SUM(cost_edu) /weight = FIRST(weight).

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR.sav'.
* Add itemcode and source.
COMPUTE source = 3.
COMPUTE itemcode = 4016.
COMPUTE category = 41.
EXECUTE.
ADD VALUE LABELS itemcode 4016 'Education provided by the State'.
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR.sav'
  /COMPRESSED.

* Aggregate total household consumption and compute per capita consumption.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp4.sav'.
ADD FILES /FILE=*
 /RENAME (dropit = d0)
 /FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR.sav'
 /DROP= d0.
EXECUTE.
SORT CASES BY
  stratum (A) dzongkha (A) town (A) block (A) houseno (A) itemcode (A) source
  (A) .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Consumption by'+
 ' item and source.sav'
  /COMPRESSED.

* Aggregate.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Consumption by'+
 ' item and source.SAV'.
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data/Consumption by category and source.SAV'
  /BREAK=stratum dzongkha town block houseno category source
  /exp_annu = SUM(exp_annu) /weight = FIRST(weight).
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data/Consumption total by source.SAV'
  /BREAK=stratum dzongkha town block houseno source
  /exp_annu = SUM(exp_annu) /weight = FIRST(weight).
* Same files, but without imputed data on education provided by the state.
FILTER OFF.
USE ALL.
SELECT IF(itemcode<>4016).
EXECUTE .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Consumption by'+
 ' item and source without imputed State education.sav'
  /COMPRESSED.
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data/Consumption by category and source' +
  ' without imputed State education.SAV'
  /BREAK=stratum dzongkha town block houseno category source
  /exp_annu = SUM(exp_annu) /weight = FIRST(weight).
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data/Consumption total by source' +
  ' without imputed State education.SAV'
  /BREAK=stratum dzongkha town block houseno source
  /exp_annu = SUM(exp_annu) /weight = FIRST(weight).


* Generate the same files without source.
* --------------------------------------.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Consumption by item'+
 ' and source.sav'.
FILTER OFF.
USE ALL.
SELECT IF(category <= 6).
EXECUTE .
SORT CASES BY
  stratum (A) dzongkha (A) town (A) block (A) houseno (A) itemcode (A) .
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp1.sav'
  /BREAK=stratum dzongkha town block houseno itemcode
  /category = FIRST(category)
  /exp_annu = SUM(exp_annu).
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Consumption by item'+
 ' and source.sav'.
FILTER OFF.
USE ALL.
SELECT IF(category > 6 and category <= 14).
EXECUTE .
SORT CASES BY
  stratum (A) dzongkha (A) town (A) block (A) houseno (A) itemcode (A) .
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp2.sav'
  /BREAK=stratum dzongkha town block houseno itemcode
  /category = FIRST(category)
  /exp_annu = SUM(exp_annu).
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Consumption by item'+
 ' and source.sav'.
FILTER OFF.
USE ALL.
SELECT IF(category > 14 and category <= 25).
EXECUTE .
SORT CASES BY
  stratum (A) dzongkha (A) town (A) block (A) houseno (A) itemcode (A) .
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp3.sav'
  /BREAK=stratum dzongkha town block houseno itemcode
  /category = FIRST(category)
  /exp_annu = SUM(exp_annu).
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Consumption by item'+
 ' and source.sav'.
FILTER OFF.
USE ALL.
SELECT IF(category > 25).
EXECUTE .
SORT CASES BY
  stratum (A) dzongkha (A) town (A) block (A) houseno (A) itemcode (A) .
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp4.sav'
  /BREAK=stratum dzongkha town block houseno itemcode
  /category = FIRST(category)
  /exp_annu = SUM(exp_annu).
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp1.sav'.
ADD FILES /FILE=*
 /FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp2.sav'.
EXECUTE.
ADD FILES /FILE=*
 /FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp3.sav'.
EXECUTE.
ADD FILES /FILE=*
 /FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp4.sav'.
EXECUTE.
SORT CASES BY
  stratum (A) dzongkha (A) town (A) block (A) houseno (A) itemcode (A) .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Consumption by'+
 ' item.sav'
  /COMPRESSED.
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data/Consumption by category.sav'
  /BREAK=stratum dzongkha town block houseno category
  /exp_annu = SUM(exp_annu).
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data/Consumption total.sav' 
  /BREAK=stratum dzongkha town block houseno 
  /exp_annu = SUM(exp_annu).


GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Consumption by'+
 ' item.sav'.
FILTER OFF.
USE ALL.
SELECT IF(itemcode<>4016).
EXECUTE .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Consumption by'+
 ' item without imputed State Education.sav'
  /COMPRESSED.
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data/Consumption by category' +
  ' without imputed State Education.sav'
  /BREAK=stratum dzongkha town block houseno category
  /exp_annu = SUM(exp_annu).
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data/Consumption total' +
  ' without imputed State Education.sav' /BREAK=stratum dzongkha town block houseno 
  /exp_annu = SUM(exp_annu).

* Compute per capita consumption.
* ------------------------------.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Block2_edited.sav'.
WEIGHT 
   OFF .
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work/AGGR.SAV'
  /BREAK=stratum dzongkha town block houseno
  /HH_size 'Household size' = N(idno).
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Consumption total.SAV'.
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR.sav'
 /BY stratum dzongkha town block houseno.
EXECUTE.
COMPUTE pc_cons = exp_annu/hh_size .
EXECUTE.
COMPUTE pcc_t_mo = pc_cons/12.
COMPUTE hhc_t_mo = exp_annu/12.
EXECUTE .
VARIABLE LABELS pc_cons 'Per capita annual consumption'
               /pcc_t_mo 'Per capita monthly total consumption' 
               /hhc_t_mo 'Household monthly total consumption' .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Consumption total.SAV'
  /COMPRESSED.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Consumption total' +
  ' without imputed State Education.sav'.
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR.sav'
 /BY stratum dzongkha town block houseno.
EXECUTE.
COMPUTE pc_cons = exp_annu/hh_size .
EXECUTE.
COMPUTE pcc_t_mo = pc_cons/12.
COMPUTE hhc_t_mo = exp_annu/12.
EXECUTE .
VARIABLE LABELS pc_cons 'Per capita annual consumption'
               /pcc_t_mo 'Per capita monthly total consumption' 
               /hhc_t_mo 'Household monthly total consumption' .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Consumption total' +
  ' without imputed State Education.sav' 
  /COMPRESSED.


* Computation of Paachse Index and Laspeyres Index.
* ================================================.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Block8_edited.SAV'.
* Identify the quantity unit most frequently used for each item.
USE ALL.
COMPUTE filter_$=(q2_quant>0 and q5_value>0).
FILTER BY filter_$.
EXECUTE .
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp.sav'
  /BREAK=itemcode q4_unit
  /cases = N(q5_value).
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp.sav'.
SORT CASES BY
  itemcode (A) cases (D) .
COMPUTE keepit = 0.
EXECUTE.
* All standard codes are to be kept, if the number of cases is >=100.
IF (itemcode=1111 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1112 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1113 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1114 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1119 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1120 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1136 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1131 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1132 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1133 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1134 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1137 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1140 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1211 and q4_unit=99 and cases>=100) keepit= 1 .
IF (itemcode=1212 and q4_unit=99 and cases>=100) keepit= 1 .
IF (itemcode=1215 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1219 and q4_unit=99 and cases>=100) keepit= 1 .
IF (itemcode=1222 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1223 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1224 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1225 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1300 and q4_unit=30 and cases>=100) keepit= 1 .
IF (itemcode=1410 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1420 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1430 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1511 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1512 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1513 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1514 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1515 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1519 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1521 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1522 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1523 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1529 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1611 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1612 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1613 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1614 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1615 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1616 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1619 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1621 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1622 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1623 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1624 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1625 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1626 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1627 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1628 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1629 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1630 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1631 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1632 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1633 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1639 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1711 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1712 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1720 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1731 and q4_unit=99 and cases>=100) keepit= 1 .
IF (itemcode=1732 and q4_unit=99 and cases>=100) keepit= 1 .
IF (itemcode=1733 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1734 and q4_unit=99 and cases>=100) keepit= 1 .
IF (itemcode=1735 and q4_unit=99 and cases>=100) keepit= 1 .
IF (itemcode=1739 and q4_unit=99 and cases>=100) keepit= 1 .
IF (itemcode=1741 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1742 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1743 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1746 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1749 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1750 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1760 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1770 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1780 and q4_unit=66 and cases>=100) keepit= 1 .
IF (itemcode=1813 and q4_unit=99 and cases>=100) keepit= 1 .
IF (itemcode=1814 and q4_unit=99 and cases>=100) keepit= 1 .
IF (itemcode=1815 and q4_unit=99 and cases>=100) keepit= 1 .
IF (itemcode=1811 and q4_unit=99 and cases>=100) keepit= 1 .
IF (itemcode=1812 and q4_unit=99 and cases>=100) keepit= 1 .
IF (itemcode=1821 and q4_unit=99 and cases>=100) keepit= 1 .
IF (itemcode=1822 and q4_unit=99 and cases>=100) keepit= 1 .
IF (itemcode=1823 and q4_unit=99 and cases>=100) keepit= 1 .
EXECUTE .

*************************************************************************.
*************************************************************************.
* Add manually keepit = 1 for the quantity unit to be used, for each item. 
*************************************************************************.
*************************************************************************.

SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\List units for'+
 ' Paachse.sav'
  /COMPRESSED.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\List units for'+
 ' Paachse.sav'.
FILTER OFF.
USE ALL.
SELECT IF(keepit=1).
EXECUTE .
SORT CASES BY
  itemcode (A) q4_unit (A) .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\List units for'+
 ' Paachse.sav'
  /COMPRESSED.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Block8_edited.SAV'.
SORT CASES BY
  itemcode (A) q4_unit (A).
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\List units for Paachse.sav'
 /BY itemcode q4_unit.
EXECUTE.
FILTER OFF.
USE ALL.
SELECT IF(keepit=1).
EXECUTE .
SORT CASES BY
  stratum (A) dzongkha (A) town (A) block (A) houseno (A) itemcode (A) .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp1.sav'
  /DROP keepit
  /COMPRESSED.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp1.SAV'.
SORT CASES BY
  stratum (A) itemcode (A) .
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR1.SAV'
  /BREAK=stratum itemcode
  /cases_st = N(houseno).
SORT CASES BY
  stratum (A) dzongkha (A) itemcode (A) .
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR2.SAV'
  /BREAK=stratum dzongkha itemcode
  /cases_dz = N(houseno).
SORT CASES BY
  stratum (A) dzongkha (A) town (A) itemcode (A) .
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR3.SAV'
  /BREAK=stratum dzongkha town itemcode
  /cases_to = N(houseno).

SORT CASES BY
  stratum (A) itemcode (A) .
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR1.SAV'
 /BY stratum itemcode.
EXECUTE.

SORT CASES BY
  stratum (A) dzongkha (A) itemcode (A) .
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR2.SAV'
 /BY stratum dzongkha itemcode.
EXECUTE.

SORT CASES BY
  stratum (A) dzongkha (A) town (A) itemcode (A) .
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR3.SAV'
 /BY stratum dzongkha town itemcode.
EXECUTE.

AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp1.sav'
  /BREAK=stratum dzongkha town block houseno itemcode
  /q2_quant = SUM(q2_quant) /q5_value = SUM(q5_value) 
  /cases_st = FIRST(cases_st) /cases_dz = FIRST(cases_dz) /cases_to = FIRST(cases_to)  
  /weight = FIRST(weight).

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp1.SAV'.
FILTER OFF.
USE ALL.
SELECT IF(q2_quant>0 and q5_value>0).
EXECUTE .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp1.sav'
  /COMPRESSED.
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR4.SAV'
  /BREAK=stratum dzongkha town block houseno
  /totvalue = SUM(q5_value).
SORT CASES BY
  stratum (A) dzongkha (A) town (A) block (A) houseno (A) .
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR4.SAV'
 /BY stratum dzongkha town block houseno.
EXECUTE.
COMPUTE share = q5_value/totvalue .
COMPUTE unitpr = q5_value/q2_quant .
EXECUTE .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp1.sav'
  /COMPRESSED.

SORT CASES BY
  stratum (A) itemcode (A).
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR1.SAV'
 /BY stratum itemcode.
EXECUTE.
SORT CASES BY
  stratum (A) dzongkha (A) itemcode (A).
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR2.SAV'
 /BY stratum dzongkha itemcode.
EXECUTE.
SORT CASES BY
  stratum (A) dzongkha (A) town (A) itemcode (A).
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR3.SAV'
 /BY stratum dzongkha town itemcode.
EXECUTE.


* Produce table of median of unit price, at different levels.

WEIGHT BY
   weight.

* Median at national level.
COMPUTE item = itemcode.
EXECUTE.
TABLES
  /FORMAT BLANK MISSING('.')
  /OBSERVATION= item unitpr
  /GBASE=CASES
  /TABLE=itemcode  BY item + unitpr
  /STATISTICS
  mean( item)
  median( unitpr)
  mean ( unitpr).

* Median at Stratum level.
COMPUTE geo = stratum*10000+itemcode .
EXECUTE .
TABLES
  /FORMAT BLANK MISSING('.')
  /OBSERVATION= unitpr
  /GBASE=CASES
  /TABLE=geo  BY unitpr
  /STATISTICS
  median( unitpr)
  mean( unitpr).

* Median at Dzongkha level.
COMPUTE geo = stratum*1000000+dzongkha*10000+itemcode .
EXECUTE .
TABLES
  /FORMAT BLANK MISSING('.')
  /OBSERVATION= unitpr
  /GBASE=CASES
  /TABLE=geo  BY unitpr
  /STATISTICS
  median( unitpr)
  mean( unitpr).

* Median at Town level.
COMPUTE geo = stratum*100000000+dzongkha*1000000+town*10000+itemcode .
EXECUTE .
TABLES
  /FORMAT BLANK MISSING('.')
  /OBSERVATION= unitpr
  /GBASE=CASES
  /TABLE=geo  BY unitpr
  /STATISTICS
  median( unitpr)
  mean( unitpr).


**********************************************.
**********************************************.
* Manually save this information in data files.
**********************************************.
**********************************************.

* Decompose substring geo and merge files with temp1.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\Median Unit Price'+
 ' Stratum.sav'.
STRING geos (A8).
COMPUTE geos = STRING(geo,F5) .
EXECUTE .
STRING stratums (A1).
STRING items (A4).
COMPUTE stratums = SUBSTR(geos,1) .
COMPUTE items = SUBSTR(geos,2,4).
EXECUTE .
COMPUTE stratum = NUMBER(stratums,F1).
COMPUTE itemcode = NUMBER(items,F4).
EXECUTE.
SORT CASES BY
  stratum (A) itemcode (A) .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\Median Unit'+
 ' Price Stratum.sav'
  /COMPRESSED.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\Median Unit Price'+
 ' Dzongkha.sav'.
STRING geos (A8).
COMPUTE geos = STRING(geo,F7) .
EXECUTE .
STRING stratums (A1).
STRING dzongs (A2).
STRING items (A4).
COMPUTE stratums = SUBSTR(geos,1) .
COMPUTE dzongs = SUBSTR(geos, 2,2).
COMPUTE items = SUBSTR(geos,4,4).
EXECUTE .
COMPUTE stratum = NUMBER(stratums,F1).
COMPUTE dzongkha = NUMBER(dzongs,F2).
COMPUTE itemcode = NUMBER(items,F4).
EXECUTE.
SORT CASES BY
  stratum (A) dzongkha (A) itemcode (A) .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\Median Unit'+
 ' Price Dzongkha.sav'
  /COMPRESSED.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\Median Unit Price'+
 ' Town.sav'.
STRING geos (A9).
COMPUTE geos = STRING(geo,F9) .
EXECUTE .
STRING stratums (A1).
STRING dzongs (A2).
STRING towns (A2).
STRING items (A4).
COMPUTE stratums = SUBSTR(geos,1) .
COMPUTE dzongs = SUBSTR(geos,2,2).
COMPUTE towns = SUBSTR(geos,4,2).
COMPUTE items = SUBSTR(geos,6,4).
EXECUTE .
COMPUTE stratum = NUMBER(stratums,F1).
COMPUTE dzongkha = NUMBER(dzongs,F2).
COMPUTE town = NUMBER(towns,F2).
COMPUTE itemcode = NUMBER(items,F4).
EXECUTE.
SORT CASES BY
  stratum (A) dzongkha (A) town (A) itemcode (A) .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\Median Unit'+
 ' Price Town.sav'
  /COMPRESSED.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp1.sav'.
SORT CASES BY
  stratum (A) itemcode (A) .
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\Median Unit Price'+
 ' Stratum.sav'
 /RENAME (geo geos items stratums = d0 d1 d2 d3)
 /BY stratum itemcode
 /DROP= d0 d1 d2 d3.
EXECUTE.
SORT CASES BY
  stratum (A) dzongkha (A) itemcode (A) .
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\Median Unit Price'+
 ' Dzongkha.sav'
 /RENAME (dzongs geo geos items stratums = d0 d1 d2 d3 d4)
 /BY stratum dzongkha itemcode
 /DROP= d0 d1 d2 d3 d4.
EXECUTE.
SORT CASES BY
  stratum (A) dzongkha (A) town (A) itemcode (A) .
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\Median Unit Price'+
 ' Town.sav'
 /RENAME (dzongs geo geos items stratums towns = d0 d1 d2 d3 d4 d5)
 /BY stratum dzongkha town itemcode
 /DROP= d0 d1 d2 d3 d4 d5.
EXECUTE.
IF (cases_to>=15) median = med_to .
EXECUTE .
IF (MISSING(median) and cases_dz>=15) median = med_dz .
EXECUTE .
IF (MISSING(median)) median = med_st .
EXECUTE .
SORT CASES BY
  itemcode (A) .
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\Median Unit Price'+
 ' National.sav'
 /BY itemcode.
EXECUTE.
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp1.sav'
  /COMPRESSED.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp1.sav'.
COMPUTE ratio = share*(med_nat/median) .
EXECUTE .
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work/AGGR.SAV'
  /BREAK=stratum dzongkha town block houseno
  /ratio = SUM(ratio) /weight = FIRST(weight).
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR.sav'.
COMPUTE paachse = 1/ratio .
EXECUTE .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Paachse Index.sav'
  /DROP ratio
  /COMPRESSED.

WEIGHT BY
   weight.
TABLES
  /FORMAT BLANK MISSING('.')
  /OBSERVATION= paachse
  /GBASE=CASES
  /FTOTAL= $t000001 "Total"
  /TABLE=stratum + $t000001  BY paachse
  /STATISTICS
  mean( paachse)
  median( paachse).
TABLES
  /FORMAT BLANK MISSING('.')
  /OBSERVATION= paachse
  /GBASE=CASES
  /FTOTAL= $t000002 "Total"
  /TABLE=stratum > dzongkha + $t000002  BY paachse
  /STATISTICS
  mean( paachse)
  median( paachse).


















* Computation of a Laspeyres regional price deflator.
* based on consumption of poorest 40%.
* ==================================================.

* Compute the consumption basket representative of the poorest 40% of population .
* (based on nominal per capita expenditure).
* Compute quantity share of each selected item.
* Compute value of this basket of goods in each region.
* Select one region as the reference (index=100), and compute the index for others.

* Compute household size.
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Block2_edited.sav'.
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\hhsize.sav'
  /BREAK=stratum dzongkha town block houseno
  /hh_size = NU(idno) /weight = FIRST(weight).

* Add household size to Food expenditure file.
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Food expenditure by'+
 ' item.SAV'.
WEIGHT
  BY weight .
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\hhsize.sav'
 /RENAME (weight = d0)
 /BY stratum dzongkha town block houseno
 /DROP= d0.
EXECUTE.
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Food'+
 ' expenditure by item.SAV'
  /COMPRESSED.

* Identify poorest 40% households (based on per capita total consumption).

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Consumption'+
 ' total.SAV'.
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\hhsize.sav'
 /BY stratum dzongkha town block houseno.
EXECUTE.
COMPUTE pc_cons = exp_annu/hh_size .
COMPUTE popweigh = hh_size*weight .
EXECUTE .
WEIGHT
  BY popweigh .
RANK
  VARIABLES=pc_cons  (A) /RANK /NTILES (5) /PRINT=NO
  /TIES=MEAN .
FILTER OFF.
USE ALL.
SELECT IF(npc_cons=1 or npc_cons=2).
EXECUTE .
SORT CASES BY
  stratum (A) dzongkha (A) town (A) block (A) houseno (A) .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\poor40.sav'
  /COMPRESSED.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Food expenditure by'+
 ' item.SAV'.
SORT CASES BY
  stratum (A) dzongkha (A) town (A) block (A) houseno (A) .
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\poor40.sav'
 /RENAME (exp_annu hh_size npc_cons pc_cons rpc_cons weight = d0 d1 d2 d3 d4
  d5)
 /BY stratum dzongkha town block houseno
 /DROP= d0 d1 d2 d3 d4 d5.
EXECUTE.
FILTER OFF.
USE ALL.
SELECT IF(popweigh>0).
EXECUTE .
WEIGHT
  BY weight .
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work/AGGR.SAV'
  /BREAK=itemcode
  /exp_item = SUM(exp_annu).
COMPUTE ctry = 1 .
EXECUTE .
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR1.SAV'
  /BREAK=ctry
  /exp_tot = SUM(exp_annu).

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR.sav'.
COMPUTE ctry = 1 .
EXECUTE .
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR1.SAV'
 /BY ctry.
EXECUTE.
COMPUTE shareit = exp_item/exp_tot .
EXECUTE .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\Basket40.sav'
  /COMPRESSED.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\Median Unit Price'+
 ' Stratum.sav'.
SORT CASES BY
  itemcode (A) .
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\Basket40.sav'
 /RENAME (ctry exp_item exp_tot = d0 d1 d2)
 /BY itemcode
 /DROP= d0 d1 d2.
EXECUTE.
COMPUTE cost_med = shareit*med_st .
COMPUTE cost_mea = shareit*mean_st .
EXECUTE .
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR2.SAV'
  /BREAK=stratum  
  /cost_med = SUM(cost_med) /cost_mea = SUM(cost_mea).
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR2.SAV'.
