***********************************************************.
* SPSS PROGRAM FOR EDITING THE NON-FOOD EXPENDITURE        .
***********************************************************.

*********************************.
* Block 9.
*********************************.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Block9_original.sav'.
* Look for outliers (> mean + 2* STD deviation by item, by dzongkha.
WEIGHT
  BY weight .
COMPUTE exp_annu = q2_cash + q3_kind .
EXECUTE .
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work/AGGR.SAV'
  /BREAK=stratum dzongkha itemcode
  /mean = MEAN(exp_annu) /stdev = SD(exp_annu).
SORT CASES BY
  stratum (A) dzongkha (A) itemcode (A) .
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR.SAV'
 /BY stratum dzongkha itemcode.
EXECUTE.
IF (exp_annu>(mean+3*stdev)) outlier = 1 .
EXECUTE .
WEIGHT
   OFF.
FREQUENCIES
  VARIABLES=outlier
  /ORDER=  ANALYSIS .

* Fix outliers.

SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS'+
 ' 2003\Data\Block9_edited.sav'
  /DROP mean stdev outlier
  /COMPRESSED.

*********************************.
* Block 10.
*********************************.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS'+
 ' 2003\Data\Block10_original.sav'.
IF (quantity>0) pc_cost = amount/quantity .
EXECUTE .
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work/AGGR.SAV'
  /BREAK=stratum itemcode
  /mean = MEAN(amount) /stddev = SD(amount).
SORT CASES BY
  stratum (A) itemcode (A) .
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR.SAV'
 /BY stratum itemcode.
EXECUTE.
IF (pc_cost>(mean+2*stddev)) outlier = 1 .
IF (quantity > 20 and itemcode<>3041) outlier = 1.
IF (amount = 0) outlier = 1.
IF (quantity>10000 and itemcode=3041) outlier = 1.
EXECUTE .
TABLES
  /FORMAT BLANK MISSING('.')
  /GBASE=CASES
  /FTOTAL= $t000001 "Total"
  /TABLE=itemcode + $t000001  BY outlier > (STATISTICS)  .

* Manual check and corrections.

SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS'+
 ' 2003\Data\Block10_edited.sav'
  /DROP mean stddev outlier pc_cost
  /COMPRESSED.


*******************************************************************.
* Create the files of "non-food expenditure" at different levels   .
* Separate records for received and purchased items                .
* Purchased items are "source 1" ; received items are "source 3"   .
* Data from Block 10 (produced) will be added, with "source 2"     .
* A variable identifying the category of items is created          .
*******************************************************************.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Block9_edited.sav'.
FILTER OFF.
USE ALL.
SELECT IF(q2_cash>0).
EXECUTE .
COMPUTE exp_annu = q2_cash .
COMPUTE source = 1.
EXECUTE .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp1.sav'
  /DROP q2_cash q3_kind
  /COMPRESSED.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Block9_edited.sav'.
FILTER OFF.
USE ALL.
SELECT IF(q3_kind>0).
EXECUTE .
COMPUTE exp_annu = q3_kind .
COMPUTE source = 3.
EXECUTE .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp2.sav'
  /DROP q2_cash q3_kind
  /COMPRESSED.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Block10_edited.sav'.
COMPUTE source = 2.
EXECUTE .
RENAME VARIABLE (amount=exp_annu).
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp3.sav'
  /DROP unitcode quantity 
  /COMPRESSED.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp1.sav'.
ADD FILES /FILE=*
 /FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp2.sav'.
EXECUTE.
ADD FILES /FILE=*
 /FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp3.sav'.
EXECUTE.
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Non food'+
 ' expenditure by item and source.SAV'
  /COMPRESSED.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Non food'+
 ' expenditure by item and source.SAV'.
VARIABLE LABELS source 'Source'.
VALUE LABELS source 1 'Purchased'
                    2 'Produced'
                    3 'Received'.
SORT CASES BY
  stratum (A) dzongkha (A) town (A) block (A) itemcode (A) source (A) .
FILTER OFF.
USE ALL.
SELECT IF(exp_annu>0).
EXECUTE .

SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Non food'+
 ' expenditure by item and source.SAV'
  /COMPRESSED.

* Add education from block 2.
* --------------------------.
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Block2_edited.sav'.
FILTER OFF.
USE ALL.
SELECT IF(b22_q13a>0).
EXECUTE .
RENAME VARIABLES (b22_q13a=exp_annu).
COMPUTE itemcode = 4011.
COMPUTE source = 1.
EXECUTE.
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp.sav'
  /KEEP stratum dzongkha town block houseno source itemcode exp_annu weight
  /COMPRESSED.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Block2_edited.sav'.
FILTER OFF.
USE ALL.
SELECT IF(b22_q13b>0).
EXECUTE .
RENAME VARIABLES (b22_q13b=exp_annu).
COMPUTE itemcode = 4012.
COMPUTE source = 1.
EXECUTE.
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp1.sav'
  /KEEP stratum dzongkha town block houseno source itemcode exp_annu weight
  /COMPRESSED.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Block2_edited.sav'.
FILTER OFF.
USE ALL.
SELECT IF(b22_q13c>0).
EXECUTE .
RENAME VARIABLES (b22_q13c=exp_annu).
COMPUTE itemcode = 4013.
COMPUTE source = 1.
EXECUTE.
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp2.sav'
  /KEEP stratum dzongkha town block houseno source itemcode exp_annu weight
  /COMPRESSED.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Block2_edited.sav'.
FILTER OFF.
USE ALL.
SELECT IF(b22_q13d>0).
EXECUTE .
RENAME VARIABLES (b22_q13d=exp_annu).
COMPUTE itemcode = 4014.
COMPUTE source = 1.
EXECUTE.
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp3.sav'
  /KEEP stratum dzongkha town block houseno source itemcode exp_annu weight
  /COMPRESSED.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Block2_edited.sav'.
FILTER OFF.
USE ALL.
SELECT IF(b22_q13e>0).
EXECUTE .
RENAME VARIABLES (b22_q13e=exp_annu).
COMPUTE itemcode = 4015.
COMPUTE source = 1.
EXECUTE.
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp4.sav'
  /KEEP stratum dzongkha town block houseno source itemcode exp_annu weight
  /COMPRESSED.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp.sav'.
ADD FILES /FILE=*
 /FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp1.sav'.
EXECUTE.
ADD FILES /FILE=*
 /FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp2.sav'.
EXECUTE.
ADD FILES /FILE=*
 /FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp3.sav'.
EXECUTE.
ADD FILES /FILE=*
 /FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp4.sav'.
EXECUTE.
COMPUTE source = 1.
EXECUTE.
SORT CASES BY
  stratum (A) dzongkha (A) town (A) block (A) houseno (A) itemcode (A) source (A).
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work/AGGR.SAV'
  /BREAK=stratum dzongkha town block houseno itemcode 
  /exp_annu = SUM(exp_annu) / weight = FIRST(weight) / source = FIRST(source).
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Non food expenditure'+
 ' by item and source.SAV'.
ADD FILES /FILE=*
 /FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR.SAV'.
EXECUTE.
SORT CASES BY
  stratum (A) dzongkha (A) town (A) block (A) houseno (A) itemcode (A) source (A).
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Non food'+
 ' expenditure by item and source.SAV'
  /COMPRESSED.

* Add health from block 2.
* -----------------------.
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Block2_edited.sav'.
FILTER OFF.
USE ALL.
SELECT IF(b23_q25>0).
EXECUTE .
COMPUTE exp_annu = b23_q25*13.
COMPUTE itemcode = 5011.
COMPUTE source = 1.
EXECUTE.
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp.sav'
  /KEEP stratum dzongkha town block houseno source itemcode exp_annu weight
  /COMPRESSED.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Block2_edited.sav'.
FILTER OFF.
USE ALL.
SELECT IF(b23_q27>0).
EXECUTE .
COMPUTE exp_annu = b23_q27*13.
COMPUTE itemcode = 5012.
COMPUTE source = 1.
EXECUTE.
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp1.sav'
  /KEEP stratum dzongkha town block houseno source itemcode exp_annu weight
  /COMPRESSED.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp.sav'.
ADD FILES /FILE=*
 /FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp1.sav'.
EXECUTE.
SORT CASES BY
  stratum (A) dzongkha (A) town (A) block (A) houseno (A) itemcode (A) .
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work/AGGR.SAV'
  /BREAK=stratum dzongkha town block houseno itemcode source 
  /exp_annu = SUM(exp_annu) / weight = FIRST(weight) .
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Non food expenditure'+
 ' by item and source.SAV'.
ADD FILES /FILE=*
 /FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR.SAV'.
EXECUTE.
SORT CASES BY
  stratum (A) dzongkha (A) town (A) block (A) houseno (A) itemcode (A) source (A).
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Non food'+
 ' expenditure by item and source.SAV'
  /COMPRESSED.

* Add rent from block 1.
* -----------------------.
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Block1_edited.sav'.
COMPUTE source = 1.
COMPUTE exp_annu = b1_q5*12.
COMPUTE itemcode = 6011.
EXECUTE.
ADD VALUE LABELS itemcode 6011 'Rent (paid or imputed)'.
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp.sav'
  /KEEP stratum dzongkha town block houseno source itemcode exp_annu weight
  /COMPRESSED.
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Non food expenditure'+
 ' by item and source.SAV'.
ADD FILES /FILE=*
 /FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp.SAV'.
EXECUTE.
SORT CASES BY
  stratum (A) dzongkha (A) town (A) block (A) houseno (A) itemcode (A) source (A).
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Non food'+
 ' expenditure by item and source.SAV'
  /COMPRESSED.

* Add energy from block 1.
* -----------------------.
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Block1_edited.sav'.
COMPUTE source = 1.
COMPUTE exp_annu = b1_q23wa*12.
COMPUTE itemcode = 7011.
EXECUTE.
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp.sav'
  /KEEP stratum dzongkha town block houseno source itemcode exp_annu weight
  /COMPRESSED.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Block1_edited.sav'.
COMPUTE source = 1.
COMPUTE exp_annu = b1_q23ga*12.
COMPUTE itemcode = 7012.
EXECUTE.
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp1.sav'
  /KEEP stratum dzongkha town block houseno source itemcode exp_annu weight
  /COMPRESSED.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Block1_edited.sav'.
COMPUTE source = 1.
COMPUTE exp_annu = b1_q23ca*12.
COMPUTE itemcode = 7013.
EXECUTE.
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp2.sav'
  /KEEP stratum dzongkha town block houseno source itemcode exp_annu weight
  /COMPRESSED.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Block1_edited.sav'.
COMPUTE source = 1.
COMPUTE exp_annu = (b1_q23el+b1_q23ec)*6.
COMPUTE itemcode = 7014.
EXECUTE.
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp3.sav'
  /KEEP stratum dzongkha town block houseno source itemcode exp_annu weight
  /COMPRESSED.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Block1_edited.sav'.
COMPUTE source = 1.
COMPUTE exp_annu = b1_q23ke*12.
COMPUTE itemcode = 7015.
EXECUTE.
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp4.sav'
  /KEEP stratum dzongkha town block houseno source itemcode exp_annu weight
  /COMPRESSED.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Block1_edited.sav'.
COMPUTE source = 1.
COMPUTE exp_annu = b1_q24mo*b1_q24av*12.
COMPUTE itemcode = 7016.
EXECUTE.
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp5.sav'
  /KEEP stratum dzongkha town block houseno source itemcode exp_annu weight
  /COMPRESSED.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Block1_edited.sav'.
COMPUTE source = 1.
COMPUTE exp_annu = b1_q25ye*b1_q25av.
COMPUTE itemcode = 7016.
EXECUTE.
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp6.sav'
  /KEEP stratum dzongkha town block houseno source itemcode exp_annu weight
  /COMPRESSED.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp.sav'.
ADD FILES /FILE=*
 /FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp1.sav'.
EXECUTE.
ADD FILES /FILE=*
 /FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp2.sav'.
EXECUTE.
ADD FILES /FILE=*
 /FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp3.sav'.
EXECUTE.
ADD FILES /FILE=*
 /FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp4.sav'.
EXECUTE.
ADD FILES /FILE=*
 /FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp5.sav'.
EXECUTE.
ADD FILES /FILE=*
 /FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp6.sav'.
EXECUTE.

SORT CASES BY
  stratum (A) dzongkha (A) town (A) block (A) houseno (A) itemcode (A) source (A).
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work/AGGR.SAV'
  /BREAK=stratum dzongkha town block houseno itemcode source 
  /exp_annu = SUM(exp_annu) / weight = FIRST(weight) .
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Non food expenditure'+
 ' by item and source.SAV'.
ADD FILES /FILE=*
 /FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR.SAV'.
EXECUTE.
SORT CASES BY
  stratum (A) dzongkha (A) town (A) block (A) houseno (A) itemcode (A) source (A).
FILTER OFF.
USE ALL.
SELECT IF(exp_annu>0).
EXECUTE .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Non food'+
 ' expenditure by item and source.SAV'
  /COMPRESSED.

* Add remittances from Block 5.
* ----------------------------.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Block5_edited.sav'.
FILTER OFF.
USE ALL.
SELECT IF(b5_remit=1).
EXECUTE .
RECODE
  b5_q12 b5_q13 b5_q22 b5_q23 b5_q32 b5_q33 b5_q42 b5_q43 b5_q52 b5_q53
  (SYSMIS=0)  .
EXECUTE .
COMPUTE cash = b5_q12 + b5_q22 + b5_q32 + b5_q42 + b5_q52 .
COMPUTE kind = b5_q13 + b5_q23 + b5_q33 + b5_q43 + b5_q53 .
EXECUTE .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp.sav'
  /COMPRESSED.
FILTER OFF.
USE ALL.
SELECT IF(cash>0).
EXECUTE .
RENAME VARIABLES (cash=exp_annu).
COMPUTE source = 1.
COMPUTE itemcode = 8011.
EXECUTE.
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work/temp1.SAV'
  /BREAK=stratum dzongkha town block houseno
  /weight = FIRST(weight) /exp_annu = SUM(exp_annu) /source = FIRST(source)
  /itemcode = FIRST(itemcode).

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp.sav'.
FILTER OFF.
USE ALL.
SELECT IF(kind>0).
EXECUTE .
RENAME VARIABLES (kind=exp_annu).
COMPUTE source = 2.
COMPUTE itemcode = 8012.
EXECUTE.
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work/temp2.SAV'
  /BREAK=stratum dzongkha town block houseno
  /weight = FIRST(weight) /exp_annu = SUM(exp_annu) /source = FIRST(source)
 /itemcode = FIRST(itemcode).

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Non food expenditure'+
 ' by item and source.SAV'.
ADD FILES /FILE=*
 /FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp1.SAV'.
EXECUTE.
ADD FILES /FILE=*
 /FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp2.SAV'.
EXECUTE.
SORT CASES BY
  stratum (A) dzongkha (A) town (A) block (A) houseno (A) itemcode (A) .
FILTER OFF.
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Non food'+
 ' expenditure by item and source.SAV'
  /COMPRESSED.

* Create categories of items and aggregate by category .
* -----------------------------------------------------.
IF (itemcode>=2111 and itemcode<=2120) category = 21.
IF (itemcode>=2211 and itemcode<=2219) category = 22.
IF (itemcode>=2311 and itemcode<=2318) category = 23.
IF (itemcode>=2411 and itemcode<=2419) category = 24.
IF (itemcode>=2511 and itemcode<=2520) category = 25.
IF (itemcode>=2611 and itemcode<=2619) category = 26.
IF (itemcode>=2711 and itemcode<=2715) category = 27.
IF (itemcode = 3011) category =21.
IF (itemcode = 3012) category =21 .
IF (itemcode = 3013) category =21 .
IF (itemcode = 3014) category =25 .
IF (itemcode = 3015) category =26 .
IF (itemcode = 3019) category =21 .
IF (itemcode = 3021) category =25 .
IF (itemcode = 3022) category =25.
IF (itemcode = 3023) category =25 .
IF (itemcode = 3024) category =21 .
IF (itemcode = 3029) category =25 .
IF (itemcode = 3031) category =25 .
IF (itemcode = 3032) category =25 .
IF (itemcode = 3039) category =25 .
IF (itemcode = 3041) category =25 .
IF (itemcode = 3042) category =25 .
IF (itemcode = 3049) category =25 .
IF (itemcode>=4011 and itemcode<=4015) category =41 .
IF (itemcode>=5011 and itemcode<=5012) category =51 .
IF (itemcode = 6011) category =61 . 
IF (itemcode>=7011 and itemcode<=7016) category =71 . 
IF (itemcode>=8011 and itemcode<=8012) category =81 .
EXECUTE.
VARIABLE LABELS category 'Category'.
VALUE LABELS category 21 'Clothing and footwear'
                      22 'Transport and communications'
                      23 'Household operations'
                      24 'Recreation'
                      25 'Furnishing and equipment'
                      26 'Miscellaneous expenditure'
                      27 'Non consumption expenditure'
                      41 'Education'
                      51 'Health'
                      61 'Rent'
                      71 'Energy for home'
                      81 'Remittances'.
VALUE LABELS itemcode 4011 'Token fee, school dev. fund'
 			    4012 'Books, supplies'
			    4013 'Boarding fees'
  			    4014 'Private tutoring'
 			    4015 'Token fee, school dev. fund'
 			    5011 'Consultations, hospitalization'
 			    5012 'Medicines'
                      6011 'Rent'
 			    7011 'Water'
 			    7012 'Cooking gas'
			    7013 'Candles'
			    7014 'Electricity'
 			    7015 'Kerosene'
 			    7016 'Wood for cooking'
                      8011 'Remittances in cash'
                      8012 'Remittances in kind'.
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Non food'+
 ' expenditure by item and source.SAV'
  /COMPRESSED.

AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data/Non food expenditure total by source.SAV'
  /BREAK=stratum dzongkha town block houseno source
  /exp_annu 'Annual expenditure' = SUM(exp_annu).

AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data/Non food expenditure by category and source.SAV'
  /BREAK=stratum dzongkha town block houseno category source
  /exp_annu 'Annual expenditure' = SUM(exp_annu).


* Generate non-food expenditure files without source.
* --------------------------------------------------.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Non food expenditure'+
 ' by item and source.SAV'.
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Non food'+
 ' expenditure by item.SAV'
  /BREAK=stratum dzongkha town block houseno itemcode
  /exp_annu = SUM(exp_annu) /category = FIRST(category) /weight =
  FIRST(weight).

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Non food expenditure'+
 ' by item and source.SAV'.
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Non food'+
 ' expenditure by category.SAV'
  /BREAK=stratum dzongkha town block houseno category
  /exp_annu = SUM(exp_annu) /weight = FIRST(weight).

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Non food expenditure'+
 ' by item and source.SAV'.
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Non food'+
 ' expenditure total.SAV'
  /BREAK=stratum dzongkha town block houseno 
  /exp_annu = SUM(exp_annu) /weight = FIRST(weight).


* Compute per capita non-food expenditure.
* ---------------------------------------.
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Non food expenditure'+
 ' total.SAV'.
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\HH Size Nima.sav'
 /RENAME (popw weight = d0 d1)
 /BY stratum dzongkha town block houseno
 /DROP= d0 d1 .
EXECUTE.
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR.sav'
 /BY stratum dzongkha town block houseno.
EXECUTE.
COMPUTE pc_nfexp = exp_annu/hh_size .
EXECUTE.
COMPUTE pc_nf_mo = pc_nfexp/12.
COMPUTE hh_nf_mo = exp_annu/12.
EXECUTE .
VARIABLE LABELS pc_nfexp 'Per capita annual non food expenditure'
               /pc_nf_mo 'Per capita monthly non food expenditure' 
               /hh_nf_mo 'Household monthly non food expenditure' .
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Weight.sav'
 /BY stratum dzongkha town block.
EXECUTE.
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Non food'+
 ' expenditure total.SAV'
  /COMPRESSED.

WEIGHT BY
   weight.
TABLES
  /FORMAT BLANK MISSING('.')
  /OBSERVATION= pc_nfexp pc_nf_mo hh_nf_mo
  /GBASE=CASES
  /FTOTAL= $t000001 "Total"
  /TABLE=pc_nfexp > (STATISTICS) + pc_nf_mo > (STATISTICS) + hh_nf_mo >
  (STATISTICS)  BY stratum + $t000001  .



* Production of files containing all expenditures by item.
* ----------------------------------------------------------------------.
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Food expenditure by item and'+
 ' source.SAV'.
ADD FILES /FILE=*
 /FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Non food expenditure by item'+
 ' and source.SAV'.
EXECUTE.
SORT CASES BY
  stratum (A) dzongkha (A) town (A) block (A) houseno (A) itemcode (A) source
  (A) .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\All expenditure by item'+
 ' and source.sav'
  /COMPRESSED.


* Production of files containing all expenditures by category, and total.
* ----------------------------------------------------------------------.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Food expenditure by'+
 ' category.SAV'.
ADD FILES /FILE=*
 /RENAME (weight = d0)
 /FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Non food expenditure'+
 ' by category.SAV'
 /DROP= d0.
EXECUTE.
SORT CASES BY
  stratum (A) dzongkha (A) town (A) block (A) houseno (A) category (A) .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\All'+
 ' expenditure by category.SAV'
  /COMPRESSED.
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\All expenditure'+
 ' total.SAV'
  /BREAK=stratum dzongkha town block houseno
  /exp_annu 'Total annual expenditure' = SUM(exp_annu).
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\All expenditure'+
 ' total.SAV'.
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Weight.sav'
 /BY stratum dzongkha town block.
EXECUTE.
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\All expenditure'+
 ' total.SAV'
  /COMPRESSED.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\All expenditure'+
 ' total.SAV'.
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\HH Size Nima.sav'
 /RENAME (popw weight = d0 d1)
 /BY stratum dzongkha town block houseno
 /DROP= d0 d1.
EXECUTE.
COMPUTE pc_texp = exp_annu/hh_size .
EXECUTE.
COMPUTE pc_t_mo = pc_texp/12.
COMPUTE hh_t_mo = exp_annu/12.
EXECUTE .
VARIABLE LABELS pc_texp 'Per capita annual total expenditure'
               /pc_t_mo 'Per capita monthly total expenditure' 
               /hh_t_mo 'Household monthly total expenditure' .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\All'+
 ' expenditure total.SAV'
  /COMPRESSED.

WEIGHT BY
   weight .
TABLES
  /FORMAT BLANK MISSING('.')
  /OBSERVATION= pc_texp pc_t_mo hh_t_mo
  /GBASE=CASES
  /FTOTAL= $t000001 "Total"
  /TABLE=pc_texp > (STATISTICS) + pc_t_mo > (STATISTICS) + hh_t_mo >
  (STATISTICS)  BY stratum + $t000001  .


