***********************************************************************.
* SPSS program for checking range and consistency in blocks 1 to 7     .
***********************************************************************.

**************************.
* Check Block 1           .
**************************.         

* Produce frequency tables to verify that no invalid code was used and that .
* value and variable labels are okay(check tables visually).
* Check extreme values (possible outliers) for means.
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Block1_original.sav'.
WEIGHT 
   OFF .
* Replace 0 with missing in q19.
RECODE
  b1_q19_2 b1_q19_3 b1_q19_4 b1_q26kg (0=SYSMIS)  .
EXECUTE .
FREQUENCIES
  VARIABLES=b1_q1 b1_q2 b1_q3 b1_q4 b1_q6 b1_q7 b1_q8 b1_q9 b1_q10 b1_q11
  b1_q12 b1_q15bo b1_q15fi b1_q15ch b1_q16 b1_q17 b1_q18 b1_q19_1 b1_q19_2
  b1_q19_3 b1_q19_4 b1_q24mo b1_q25ye b1_q26kg
  /ORDER=  ANALYSIS .
DESCRIPTIVES
  VARIABLES=b1_q5 b1_q13km b1_q13mi b1_q14 b1_q23wa b1_q23ga b1_q23ca
  b1_q23el b1_q23ec b1_q23ke b1_q24av b1_q25av
  /STATISTICS=MEAN STDDEV MIN MAX .


* Consistency checks (produce frequency tables on the number of inconsistencies).
IF (b1_q2=1 and (~MISSING(b1_q3) or ~MISSING(b1_q4))) test = 1 .
EXECUTE .
VARIABLE LABELS test 'Owns dwelling but answer in q3 or q4'.
FREQUENCIES
  VARIABLES=test
  /ORDER=  ANALYSIS .

COMPUTE test=0.
IF (b1_q12=1 and (~MISSING(b1_q13km) or ~MISSING(b1_q13m) or ~MISSING(b1_q13mi))) test = 1 .
EXECUTE .
VARIABLE LABELS test 'Pipe in dwelling but distance declared'.
FREQUENCIES
  VARIABLES=test
  /ORDER=  ANALYSIS .

COMPUTE test=0.
IF (b1_q16=4 and (~MISSING(b1_q17))) test = 1 .
EXECUTE .
VARIABLE LABELS test 'No toilet but q17 declared'.
FREQUENCIES
  VARIABLES=test
  /ORDER=  ANALYSIS .

COMPUTE test=0.
IF ((b1_q18=2 or b1_q18=3) and (~MISSING(b1_q19_1) or ~MISSING(b1_q19_2) 
    or ~MISSING(b1_q19_3) or ~MISSING(b1_q19_4))) test = 1 .
EXECUTE .
VARIABLE LABELS test 'Has electricity but response in q19'.
FREQUENCIES
  VARIABLES=test
  /ORDER=  ANALYSIS .

SORT CASES BY
  stratum (A) dzongkha (A) town (A) block (A) houseno (A) .

SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS'+
 ' 2003\Data\Block1_edited.sav'
  /DROP hsize rehsize rerooms rebloads retloads remeters reminute 
        req14 filter_$ test 
  /COMPRESSED.


**************************.
* Check Block 2           .
**************************.         

* Q32, Q37: fix value labels.
* Fix outliers in Q13, Q14, Q25, Q47.
* Some automatic corrections are made.

* Produce frequency tables to verify that no invalid code was used and that .
* value and variable labels are okay(check tables visually).
* Check extreme values (possible outliers) for means.
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Block2_original.sav'.
WEIGHT 
   OFF .
VARIABLE LABELS  b22_q8   'Ever attended school'
                /b22_q10  'Level currently attended'
                /b22_q12  'Distance to school'
                /b23_q24a '1st reason for not consulting'
                /b23_q24b '2nd reason for not consulting'
                /b23_q24c '3rd reason for not consulting'
                /b24_Q43  'Status in secondary occupation'
                /b24_Q44  'Secondary occupation' .
VALUE LABELS b22_q15a 1 'Yes' 
                      2 'No' 
                      3 'Do not know' 
                      4 'Not concerned'
            /b23_q24a 1 'No need'
                      2 'No time'
                      3 'No money'
                      4 'No transport/too far'
                      5 'Does not trust'
                      6 'Other'
            /b23_q24b 1 'No need'
                      2 'No time'
                      3 'No money'
                      4 'No transport/too far'
                      5 'Does not trust'
                      6 'Other'
            /b23_q24c 1 'No need'
                      2 'No time'
                      3 'No money'
                      4 'No transport/too far'
                      5 'Does not trust'
                      6 'Other'
            /b23_q31  1 'Yes' 2 'No' 3 'Do not know'
            /b23_q32  1 'Yes'
                      2 'Not concerned'
                      3 'No, not available'
                      4 'No, religious/moral objection'
                      5 'No, husband/family objection'
                      6 'No, because of side effects'
                      7 'No, too expensive'
                      8 'Does not want to respond'
                      9 'Does not know' 
            /b24_q37  1 'Waiting for job to start'
                      2 'Awaiting employer reply'
                      3 'Waiting for seasonnal work'
                      4 'No job available'
                      5 'Studying'
                      6 'Taking care of home'
                      7 'Pensioner'
                      8 'Too old or disabled'
                      9 'Not healthy'
                     10 'Does not want to work'
                     11 'Other' 
            /b25_q50f 0 'Pre-school'
                     21 'Higher academic (university)'
                     31 'Religious'
                     41 'Vocational/professional'
                     99 'Does not know'
            /b25_q50m 0 'Pre-school'
                     21 'Higher academic (university)'
                     31 'Religious'
                     41 'Vocational/professional'
                     99 'Does not know'
            /b25_q51f 0 'None'
                      1 'Agriculture'
                      2 'Mining'
                      3 'Manufacturing'
                      4 'Elec.,gas.water'
                      5 'construction'
                      6 'Retail trade'
                      7 'Hotel,restaurant'
                      8 'Transport'
                      9 'Finance,real estate'
                     10 'Insurance'
                     11 'Public admin.,defence'
                     12 'Education'
                     13 'Health,social work'
                     14 'Other'
                     99 'Does not know'
            /b25_q51m 0 'None'
                      1 'Agriculture'
                      2 'Mining'
                      3 'Manufacturing'
                      4 'Elec.,gas.water'
                      5 'construction'
                      6 'Retail trade'
                      7 'Hotel,restaurant'
                      8 'Transport'
                      9 'Finance,real estate'
                     10 'Insurance'
                     11 'Public admin.,defence'
                     12 'Education'
                     13 'Health,social work'
                     14 'Other' 
                     99 'Does not know' . 
FREQUENCIES
  VARIABLES=b21_q1 b21_q2 b21_q3ag b21_q4 b21_q5 b21_q6 b22_q7dz b22_q7en
  b22_q7lo b22_q7ot b22_q8 b22_q9 b22_q10 b22_q11 b22_q12 b22_q15a b22_q15c
  b22_q15b b22_q15d b22_q15e b22_q15f b22_q15g b22_q15h b22_q15i b22_q16 b22_q17 
  b22_q18 b22_q19   b22_q20 b23_q21 b23_q23 b23_q24a b23_q24b b23_q24c b23_q26 b23_q28 
  b23_q29 b23_q30 b23_q31 b23_q32 b24_q33w b24_q33y b24_q34w b24_q34y b24_q35w
  b24_q35y b24_q36 b24_q37 b24_q38 b24_q39 b24_q40 b24_q41 b24_q42 b24_q43
  b24_q44 b24_q45 b24_q46 b24_q48a b24_q48b b24_q48c b24_q48d b24_q48e
  b24_q48f b24_q48g b24_q48h b25_q49f b25_q49m b25_q50f b25_q50m b25_q51f
  b25_q51m
  /ORDER=  ANALYSIS .
DESCRIPTIVES
  VARIABLES=b22_q13a b22_q13b b22_q13c b22_q13d b22_q13e b22_q13f b22_q14
  b23_q25 b24_q47m b24_q47s
  /STATISTICS=MEAN STDDEV MIN MAX .

* For students absent>6 month, the information on education cost    .
* is saved and added as remittence (but they are considered members).
* ------------------------------------------------------------------.
USE ALL.
COMPUTE educ = b22_q13a + b22_q13b + b22_q13c + b22_q13d + b22_q13e +
  b22_q13f .
EXECUTE .
SELECT IF((b21_q6=12 and b21_q2<>1) or (b21_q6>6 and educ>20000)).
EXECUTE .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp.sav'
  /COMPRESSED.
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Block2_original.sav'.
SORT CASES BY
  stratum (A) dzongkha (A) town (A) block (A) houseno (A) idno (A) .
COMPUTE educ = b22_q13a + b22_q13b + b22_q13c + b22_q13d + b22_q13e +
  b22_q13f .
EXECUTE .
WEIGHT 
   OFF .
RECODE
  b21_q3ag
  (0 thru 4=0)  (5 thru 9=5)  (10 thru 14=10)  (15 thru 19=15)  
  (20 thru 24=20)  (25 thru 29=25)  (30 thru 34=30)  (35 thru 39=35)  
  (40 thru 44=40)  (45 thru 49=45)  (50 thru 54=50)  (55 thru 59=55)  
  (60 thru 64=60)  (65 thru 69=65)  (70 thru 99=70)  INTO  age_gr5 .
EXECUTE .
VARIABLE LABELS age_gr5 'Age group'.
VALUE LABELS age_gr5  0  ' 0- 4'
                      5  ' 5- 9'
                      10 '10-14'
                      15 '15-19'
                      20 '20-24'
                      25 '25-29'
                      30 '30-34'
                      35 '35-39'
                      40 '40-44'
                      45 '45-49'
                      50 '50-54'
                      55 '55-59'
                      60 '60-64'
                      65 '65-69'
                      70 '70- +'.
RECODE
  b21_q3ag
  (0 thru 9=0)     (10 thru 19=10)    
  (20 thru 29=20)  (30 thru 39=30)    
  (40 thru 49=40)  (50 thru 59=50)    
  (60 thru 69=60)  (70 thru 99=70)  INTO  age_gr10 .
EXECUTE .
VARIABLE LABELS age_gr10 'Age group'.
VALUE LABELS age_gr10 0  ' 0- 9'
                      10 '10-19'
                      20 '20-29'
                      30 '30-39'
                      40 '40-49'
                      50 '50-59'
                      60 '60-69'
                      70 '70- +'.
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Block2_edited.sav'
  /COMPRESSED.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\HRoster_original.sav'.
SORT CASES BY
  stratum (A) dzongkha (A) town (A) block (A) houseno (A) idno (A) .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS'+
 ' 2003\Data\HRoster_edited.sav'
  /COMPRESSED.

* Students absent 12 months remain in datafile, but their education  .
* cost is aggregated and saved as remittance (child support)in Block5.
* ------------------------------------------------------------------------------.
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp.sav'.
COMPUTE edu_cost = b22_q13a + b22_q13b + b22_q13c + b22_q13d + b22_q13e +
  b22_q13f .
EXECUTE .
FILTER OFF.
USE ALL.
SELECT IF(b22_q9=1 and edu_cost>0 ).
EXECUTE .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp.sav'
  /COMPRESSED.
WEIGHT
   OFF.
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work/AGGR2.SAV'
  /BREAK=stratum dzongkha town block houseno
  /edu_cost = SUM(edu_cost).

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Block5_original.sav'.
SORT CASES BY
  stratum (A) dzongkha (A) town (A) block (A) houseno (A) .
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR2.SAV'
 /BY stratum dzongkha town block houseno.
EXECUTE.
IF (edu_cost>0) b5_remit = 1 .
EXECUTE .
IF (edu_cost>0 and ~MISSING(b5_q11) and ~MISSING(b5_q21)) b5_q32 = edu_cost .
IF (edu_cost>0 and ~MISSING(b5_q11) and ~MISSING(b5_q21)) b5_q33 = 0 .
IF (edu_cost>0 and ~MISSING(b5_q11) and ~MISSING(b5_q21)) b5_q31 = 1 .
IF (edu_cost>0 and ~MISSING(b5_q11) and MISSING(b5_q21)) b5_q22 = edu_cost .
IF (edu_cost>0 and ~MISSING(b5_q11) and MISSING(b5_q21)) b5_q23 = 0 .
IF (edu_cost>0 and ~MISSING(b5_q11) and MISSING(b5_q21)) b5_q21 = 1 .
IF (edu_cost>0 and MISSING(b5_q12)) b5_q12 = edu_cost .
IF (edu_cost>0 and MISSING(b5_q13)) b5_q13 = 0 .
IF (edu_cost>0 and MISSING(b5_q11)) b5_q11 = 1 .
EXECUTE .

SORT CASES BY
  stratum (A) dzongkha (A) town (A) block (A) houseno (A) .

SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS'+
 ' 2003\Data\Block5_edited.sav'
  /DROP edu_cost redzong
  /COMPRESSED.

* Back to block 2.
* Fix Q6: if > 12 replace with 0 (3 cases).
* -----------------------------------------.
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Block2_edited.sav'.
RECODE
  b21_q6  (15=0)  .
EXECUTE .

* Check that if not attending school, no data in q10 to q15.
* ---------------------------------------------------------.

COMPUTE test = 0.
IF (b22_q9<>1 and ~MISSING(b22_q10))  test = 1 .
IF (b22_q9<>1 and ~MISSING(b22_q11))  test = 1 .
IF (b22_q9<>1 and ~MISSING(b22_q12))  test = 1 .
IF (b22_q9<>1 and ~MISSING(b22_q13a)) test = 1 .
IF (b22_q9<>1 and ~MISSING(b22_q13b)) test = 1 .
IF (b22_q9<>1 and ~MISSING(b22_q13c)) test = 1 .
IF (b22_q9<>1 and ~MISSING(b22_q13d)) test = 1 .
IF (b22_q9<>1 and ~MISSING(b22_q13e)) test = 1 .
IF (b22_q9<>1 and ~MISSING(b22_q13f)) test = 1 .
IF (b22_q9<>1 and ~MISSING(b22_q14))  test = 1 .
IF (b22_q9<>1 and ~MISSING(b22_q15a)) test = 1 .
IF (b22_q9<>1 and ~MISSING(b22_q15b)) test = 1 .
IF (b22_q9<>1 and ~MISSING(b22_q15c)) test = 1 .
IF (b22_q9<>1 and ~MISSING(b22_q15d)) test = 1 .
IF (b22_q9<>1 and ~MISSING(b22_q15e)) test = 1 .
IF (b22_q9<>1 and ~MISSING(b22_q15f)) test = 1 .
IF (b22_q9<>1 and ~MISSING(b22_q15g)) test = 1 .
IF (b22_q9<>1 and ~MISSING(b22_q15h)) test = 1 .
IF (b22_q9<>1 and ~MISSING(b22_q15i)) test = 1 .
EXECUTE .
VARIABLE LABELS test 'Non-expected data in q10 to q15'.
FREQUENCIES
  VARIABLES=test
  /ORDER=  ANALYSIS .

COMPUTE test = 0.
IF (b22_q8<>1 and ~MISSING(b22_q9))   test = 1 .
IF (b22_q8<>1 and ~MISSING(b22_q10))  test = 1 .
IF (b22_q8<>1 and ~MISSING(b22_q10))  test = 1 .
IF (b22_q8<>1 and ~MISSING(b22_q11))  test = 1 .
IF (b22_q8<>1 and ~MISSING(b22_q12))  test = 1 .
IF (b22_q8<>1 and ~MISSING(b22_q13a)) test = 1 .
IF (b22_q8<>1 and ~MISSING(b22_q13b)) test = 1 .
IF (b22_q8<>1 and ~MISSING(b22_q13c)) test = 1 .
IF (b22_q8<>1 and ~MISSING(b22_q13d)) test = 1 .
IF (b22_q8<>1 and ~MISSING(b22_q13e)) test = 1 .
IF (b22_q8<>1 and ~MISSING(b22_q13f)) test = 1 .
IF (b22_q8<>1 and ~MISSING(b22_q14))  test = 1 .
IF (b22_q8<>1 and ~MISSING(b22_q15a)) test = 1 .
IF (b22_q8<>1 and ~MISSING(b22_q15b)) test = 1 .
IF (b22_q8<>1 and ~MISSING(b22_q15c)) test = 1 .
IF (b22_q8<>1 and ~MISSING(b22_q15d)) test = 1 .
IF (b22_q8<>1 and ~MISSING(b22_q15e)) test = 1 .
IF (b22_q8<>1 and ~MISSING(b22_q15f)) test = 1 .
IF (b22_q8<>1 and ~MISSING(b22_q15g)) test = 1 .
IF (b22_q8<>1 and ~MISSING(b22_q15h)) test = 1 .
IF (b22_q8<>1 and ~MISSING(b22_q15i)) test = 1 .
IF (b22_q8<>1 and ~MISSING(b22_q16))  test = 1 .
EXECUTE .
VARIABLE LABELS test 'Non-expected data in q9 to q16'.
FREQUENCIES
  VARIABLES=test
  /ORDER=  ANALYSIS .

* Fix Q15a to g: code 4 should not be used.
* ----------------------------------------.
COMPUTE test = 0.
IF (b22_q9=1 and b22_q15a = 4) test = 1.
IF (b22_q9=1 and b22_q15b = 4) test = 1.
IF (b22_q9=1 and b22_q15c = 4) test = 1.
IF (b22_q9=1 and b22_q15d = 4) test = 1.
IF (b22_q9=1 and b22_q15e = 4) test = 1.
IF (b22_q9=1 and b22_q15f = 4) test = 1.
IF (b22_q9=1 and b22_q15g = 4) test = 1.
IF (b22_q9=1 and b22_q15h = 4) test = 1.
EXECUTE.
VARIABLE LABELS test 'Child in school; should be concerned in q15'.
FREQUENCIES
  VARIABLES=test
  /ORDER=  ANALYSIS .
* Replace not concerned with does not know.
IF (b22_q9=1 and b22_q15a = 4) b22_q15a  = 3.
IF (b22_q9=1 and b22_q15b = 4) b22_q15b  = 3.
IF (b22_q9=1 and b22_q15c = 4) b22_q15c  = 3.
IF (b22_q9=1 and b22_q15d = 4) b22_q15d  = 3.
IF (b22_q9=1 and b22_q15e = 4) b22_q15e  = 3.
IF (b22_q9=1 and b22_q15f = 4) b22_q15f  = 3.
IF (b22_q9=1 and b22_q15g = 4) b22_q15g  = 3.
IF (b22_q9=1 and b22_q15h = 4) b22_q15h  = 3.
EXECUTE.

* Check skip in q17.
* -----------------.
COMPUTE test = 0.
IF (b22_q17=5 and ~MISSING(b22_q18))   test = 1 .
IF (b22_q17=5 and ~MISSING(b22_q19))   test = 1 .
EXECUTE.
VARIABLE LABELS test 'q18 and q19 expected empty'.
FREQUENCIES
  VARIABLES=test
  /ORDER=  ANALYSIS .
DO IF (b22_q17=5 and ~MISSING(b22_q18)) .
RECODE
  b22_q18  (ELSE=SYSMIS)  .
END IF .
EXECUTE .
DO IF (b22_q17=5 and ~MISSING(b22_q19)) .
RECODE
  b22_q19  (ELSE=SYSMIS)  .
END IF .
EXECUTE .

* Check skip in q21.
* -----------------.
COMPUTE test = 0.
IF (b23_q21=2 and ~MISSING(b23_q22))  test = 1.
IF (b23_q21=2 and ~MISSING(b23_q23))  test = 1.
IF (b23_q21=2 and ~MISSING(b23_q24a)) test = 1.
IF (b23_q21=2 and ~MISSING(b23_q24b)) test = 1.
IF (b23_q21=2 and ~MISSING(b23_q24c)) test = 1.
EXECUTE.
VARIABLE LABELS test 'Not sick; should be empty'.
FREQUENCIES
  VARIABLES=test
  /ORDER=  ANALYSIS .

* Q28 to 32: only for women aged 15 to 49 years.
* ---------------------------------------------.
USE ALL.
COMPUTE filter_$=(b21_q1=1 or (b21_q1=2 and (b21_q3ag<15 or b21_q3ag>49))).
FILTER BY filter_$.
EXECUTE .
FREQUENCIES
  VARIABLES=b23_q28 b23_q29 b23_q30 b23_q31 b23_q32
  /ORDER=  ANALYSIS .
DO IF (b21_q1=1 or (b21_q1=2 and (b21_q3ag<15 or b21_q3ag>49))) .
RECODE
  b23_q28 b23_q29 b23_q30 b23_q31 b23_q32  (ELSE=SYSMIS)  .
END IF .
EXECUTE .

* Q33 to 35: only if age >=10 .
* ----------------------------.
FILTER OFF.
USE ALL.
EXECUTE .
COMPUTE test = 0.
IF (b21_q3ag<10 and ~MISSING(b24_q33w))  test = 1.
IF (b21_q3ag<10 and ~MISSING(b24_q33y))  test = 1.
IF (b21_q3ag<10 and ~MISSING(b24_q34w))  test = 1.
IF (b21_q3ag<10 and ~MISSING(b24_q34y))  test = 1.
IF (b21_q3ag<10 and ~MISSING(b24_q35w))  test = 1.
IF (b21_q3ag<10 and ~MISSING(b24_q35y))  test = 1.
IF (b21_q3ag<10 and ~MISSING(b24_q36))   test = 1.
IF (b21_q3ag<10 and ~MISSING(b24_q37))   test = 1.
IF (b21_q3ag<10 and ~MISSING(b24_q38))   test = 1.
IF (b21_q3ag<10 and ~MISSING(b24_q39))   test = 1.
IF (b21_q3ag<10 and ~MISSING(b24_q40))   test = 1.
IF (b21_q3ag<10 and ~MISSING(b24_q41))   test = 1.
IF (b21_q3ag<10 and ~MISSING(b24_q42))   test = 1.
IF (b21_q3ag<10 and ~MISSING(b24_q43))   test = 1.
IF (b21_q3ag<10 and ~MISSING(b24_q44))   test = 1.
IF (b21_q3ag<10 and ~MISSING(b24_q45))   test = 1.
IF (b21_q3ag<10 and ~MISSING(b24_q46))   test = 1.
IF (b21_q3ag<10 and ~MISSING(b24_q47m))  test = 1.
IF (b21_q3ag<10 and ~MISSING(b24_q47s))  test = 1.
IF (b21_q3ag<10 and ~MISSING(b24_q48a))  test = 1.
IF (b21_q3ag<10 and ~MISSING(b24_q48b))  test = 1.
IF (b21_q3ag<10 and ~MISSING(b24_q48c))  test = 1.
IF (b21_q3ag<10 and ~MISSING(b24_q48d))  test = 1.
IF (b21_q3ag<10 and ~MISSING(b24_q48e))  test = 1.
IF (b21_q3ag<10 and ~MISSING(b24_q48f))  test = 1.
IF (b21_q3ag<10 and ~MISSING(b24_q48g))  test = 1.
IF (b21_q3ag<10 and ~MISSING(b24_q48h))  test = 1.
VARIABLE LABELS test 'Child < 10; should have no employment'.
FREQUENCIES
  VARIABLES=test
  /ORDER=  ANALYSIS .

SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS'+
 ' 2003\Work\temp.sav'
  /DROP test filter_$ dzo age sage school eage
  /COMPRESSED.
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp.sav'.
SORT CASES BY
  stratum (A) dzongkha (A) town (A) block (A) houseno (A) .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS'+
 ' 2003\Data\Block2_edited.sav'
  /COMPRESSED.

* Consistency check between school attendance, level, and age.
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Block2_edited.sav'.
IF (b21_q3ag=3  and b22_q9=1 and b22_q10 > 0)  b22_q10 = 0.
IF (b21_q3ag=4  and b22_q9=1 and b22_q10 > 0)  b22_q10 = 0.
IF (b21_q3ag=5  and b22_q9=1 and b22_q10 > 1)  b22_q10 = 1.
IF (b21_q3ag=6  and b22_q9=1 and b22_q10 > 2)  b22_q10 = 2.
IF (b21_q3ag=7  and b22_q9=1 and b22_q10 > 3)  b22_q10 = 3.
IF (b21_q3ag=8  and b22_q9=1 and b22_q10 > 4)  b22_q10 = 4.
IF (b21_q3ag=9  and b22_q9=1 and b22_q10 > 5)  b22_q10 = 5.
IF (b21_q3ag=10 and b22_q9=1 and b22_q10 > 6)  b22_q10 = 6.
IF (b21_q3ag=11 and b22_q9=1 and b22_q10 > 7)  b22_q10 = 7.
IF (b21_q3ag=12 and b22_q9=1 and b22_q10 > 8)  b22_q10 = 8.
IF (b21_q3ag=13 and b22_q9=1 and b22_q10 > 9)  b22_q10 = 9.
IF (b21_q3ag=14 and b22_q9=1 and b22_q10 > 10) b22_q10 = 10.
IF (b21_q3ag=15 and b22_q9=1 and b22_q10 > 11) b22_q10 = 11.
IF (b21_q3ag=16 and b22_q9=1 and b22_q10 > 12) b22_q10 = 12.
IF (b21_q3ag=17 and b22_q9=1 and b22_q10 > 13) b22_q10 = 13.
IF (b21_q3ag=18 and b22_q9=1 and b22_q10 > 13) b22_q10 = 13.
IF (b21_q3ag=19 and b22_q9=1 and b22_q10 > 15) b22_q10 = 15.
EXECUTE.
TABLES
  /FORMAT BLANK MISSING('.')
  /GBASE=CASES
  /TABLE=b21_q3ag  BY b22_q10 > (STATISTICS)  .
* Cases where age is too high for level attended must be manually checked.
* and corrected.
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS'+
 ' 2003\Data\Block2_edited.sav'
  /COMPRESSED.

**************************.
* Check Block 3           .
**************************.         

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Block3_original.sav'.
WEIGHT
  OFF.
FREQUENCIES
  VARIABLES=b3_q1sof b3_q1hea b3_q1fan b3_q1com b3_q1bic b3_q1cho b3_q1cam
  b3_q1tra b3_q1rad b3_q1buk b3_q1rco b3_q1cco b3_q1fri b3_q1mst b3_q1wbo
  b3_q1mov b3_q1bow b3_q1mob b3_q1bik b3_q1iro b3_q1car b3_q1wma b3_q1sma
  b3_q1tv b3_q1vcr b3_q1rgr b3_q1wat
  /ORDER=  ANALYSIS .
DESCRIPTIVES
  VARIABLES=b3_q2pig b3_q2cat b3_q2yak b3_q2buf b3_q2hor b3_q2she b3_q2goa
  b3_q2chi b3_q3orc b3_q3wet b3_q3wop b3_q3dry b3_q3dop b3_q3oth
  /STATISTICS=MEAN STDDEV MIN MAX .

* Check and fix outliers in means.

SORT CASES BY
  stratum (A) dzongkha (A) town (A) block (A) houseno (A) .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS'+
 ' 2003\Data\Block3_edited.sav'
  /DROP redzong ltotal lop reland reop repigs recattle reyaks rebuff 
        rehorses resheep regoat rechick 
  /COMPRESSED.


**************************.
* Check Block 4           .
**************************.         

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Block4_original.sav'.
WEIGHT
  OFF.
FREQUENCIES
  VARIABLES=b4_q1
  /ORDER=  ANALYSIS .
DESCRIPTIVES
  VARIABLES=b4_q2a b4_q2b 
  /STATISTICS=MEAN STDDEV MIN MAX .

* Fix outliers in time in hours and minutes.
* Check in particular for urban areas.

SORT CASES BY
  stratum (A) dzongkha (A) town (A) block (A) houseno (A) .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS'+
 ' 2003\Data\Block4_edited.sav'
  /COMPRESSED.


**************************.
* Check Block 5           .
**************************.         

* Note: Block 5 already edited partially in instructions for Block 2.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Block5_edited.sav'.
VARIABLE LABELS b5_q41 'Main uses of assistance'/
                b5_q42 'Amount sent in cash'/
                b5_q43 'Amount sent in kind'.
VARIABLE LABELS b5_q51 'Main uses of assistance'/
                b5_q52 'Amount sent in cash'/
                b5_q53 'Amount sent in kind'.
ADD VALUE LABELS b5_q41 1 'Child support'
                        2 'Medical'
                        3 'Wedding/Funeral' 
                        4 'Business'
                        5 'Food and clothing' 
                        6 'Durable goods'
                        7 'Other' 
                        8 'Multiple uses'
                        9 'Does not know' /
                 b5_q51 1 'Child support'
                        2 'Medical'
                        3 'Wedding/Funeral' 
                        4 'Business'
                        5 'Food and clothing' 
                        6 'Durable goods'
                        7 'Other' 
                        8 'Multiple uses'
                        9 'Does not know' .
WEIGHT
  OFF.
FREQUENCIES
  VARIABLES=b5_remit b5_q11 b5_q21 b5_q31 b5_q41 b5_q51
  /ORDER=  ANALYSIS .
DESCRIPTIVES
  VARIABLES=b5_q12 b5_q13 b5_q22 b5_q23 b5_q32 b5_q33 b5_q42 b5_q43 b5_q52
  b5_q53
  /STATISTICS=MEAN STDDEV MIN MAX .

* Check for outliers in means.

SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS'+
 ' 2003\Work\temp.sav'
  /COMPRESSED.
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp.sav'.
SORT CASES BY
  stratum (A) dzongkha (A) town (A) block (A) houseno (A) .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS'+
 ' 2003\Data\Block5_edited.sav'
  /COMPRESSED.

**************************.
* Check Block 6           .
**************************.         

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Block6_original.sav'.
WEIGHT
  OFF.
RECODE
  b6_q41 b6_q42 b6_q43 b6_q44 b6_q71 b6_q72 b6_q73  (0=SYSMIS)  .
EXECUTE .
VARIABLE LABELS  b6_q41   '1st source of credit'
                /b6_q42   '2nd source of credit'
                /b6_q43   '3rd source of credit'
                /b6_q44   '4th source of credit'
                /b6_q5ban 'Owes money to a bank'
                /b6_q5bdf 'Owes money to BDFC/RSCB'
                /b6_q5rel 'Owes money to relatives/friends'
                /b6_q5ngo 'Owes money to others (NGO,etc)'.
VALUE LABELS  b6_q5ban 1 'Yes'  2 'No'  3 'Do not know'
             /b6_q5bdf 1 'Yes'  2 'No'  3 'Do not know'.
FREQUENCIES
  VARIABLES=b6_q1mst b6_q1mav b6_q1maf b6_q1qua b6_q1wti b6_q2 b6_q3fre
  b6_q3cos b6_q3tim b6_q41 b6_q42 b6_q43 b6_q44 b6_q5ban b6_q5bdf b6_q5rel
  b6_q5ngo b6_q6 b6_q71 b6_q72 b6_q73
  /ORDER=  ANALYSIS .
SORT CASES BY
  stratum (A) dzongkha (A) town (A) block (A) houseno (A) .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS'+
 ' 2003\Data\Block6_edited.sav'
  /DROP redzong remonths filter_$
  /COMPRESSED.


**************************.
* Check Block 7           .
**************************.         

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Block7_original.sav'.
WEIGHT
  OFF.
VARIABLE LABELS b7_q11 'Source of income - 1st'/
                b7_q12 'Source of income - 2nd'/
                b7_q13 'Source of income - 3rd'.
RECODE
  b7_q11 b7_q12 b7_q13 (0=SYSMIS) .
FREQUENCIES
  VARIABLES=b7_q11 b7_q12 b7_q13
  /ORDER=  ANALYSIS .
SORT CASES BY
  stratum (A) dzongkha (A) town (A) block (A) houseno (A) .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS'+
 ' 2003\Data\Block7_edited.sav'
  /DROP redzong 
  /COMPRESSED.







