***************************************************************.
* SPSS program for computing the poverty line and the poverty  .
* and inequality indicators                                    .
***************************************************************.

* Select the "poorest" 40% households, based on per capita nominal .
* total consumption.
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Consumption'+
 ' total.SAV'.
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\hhsize.sav'
 /BY stratum dzongkha town block houseno.
EXECUTE.
COMPUTE pc_cons = exp_annu/hh_size .
COMPUTE popweigh = hh_size*weight .
EXECUTE .
WEIGHT
  BY popweigh .
RANK
  VARIABLES=pc_cons  (A) /RANK /NTILES (5) /PRINT=NO
  /TIES=MEAN .
FILTER OFF.
USE ALL.
SELECT IF(npc_cons=1 or npc_cons=2).
EXECUTE .
SORT CASES BY
  stratum (A) dzongkha (A) town (A) block (A) houseno (A) .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\poor40.sav'
  /COMPRESSED.

* For urban.
* ---------.
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Food expenditure by'+
 ' item.SAV'.
SORT CASES BY
  stratum (A) dzongkha (A) town (A) block (A) houseno (A) itemcode (A) .
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\poor40.sav'
 /RENAME (exp_annu npc_cons pc_cons rpc_cons weight = d0 d1 d2 d3 d4)
 /BY stratum dzongkha town block houseno
 /DROP= d0 d1 d2 d3 d4 .
EXECUTE.
* Select only poorest 40 percent.
FILTER OFF.
USE ALL.
SELECT IF(popweigh>0).
EXECUTE .
* Compute expenditure per capita on each food item to establish consumption basket.
WEIGHT
  BY weight .
USE ALL.
COMPUTE filter_$=(stratum=1).
FILTER BY filter_$.
EXECUTE .
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work/AGGR.SAV'
  /BREAK=itemcode
  /stratum = FIRST(stratum) / totexp = SUM(exp_annu) .
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR1.SAV'
  /BREAK=stratum dzongkha town block houseno
  /weight = FIRST(weight) /hh_size = FIRST(hh_size).
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR1.SAV'.
WEIGHT
  BY weight .
COMPUTE cntry = 1 .
EXECUTE .
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR2.SAV'
  /BREAK=cntry
  /populat = SUM(hh_size).
* Estimate the quantity by dividing expenditure by median unit prices at stratum level.
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR.sav'.
COMPUTE cntry = 1 .
EXECUTE .
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR2.SAV'
 /BY cntry.
EXECUTE.
FILTER OFF.
USE ALL.
SELECT IF(itemcode<1899).
EXECUTE .
COMPUTE exp_item = totexp/populat .
EXECUTE .
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\Median Unit Price'+
 ' Stratum.sav'
 /BY stratum itemcode.
EXECUTE.
COMPUTE quant_it = exp_item/med_st .
COMPUTE quan_day = quant_it/365 .
EXECUTE .
* Convert Kg to grams, and L to ml.
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\Standard Codes by'+
 ' Item.sav'
 /BY itemcode.
EXECUTE.
IF (std_code=66 or std_code=99) quan_day = quan_day*1000 .
EXECUTE .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp1a.SAV'
  /COMPRESSED.
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp1a.SAV'.
*ADD FILES /FILE=*
* /FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp2a.SAV'.
*EXECUTE.
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp3.sav'
  /BREAK=itemcode
  /stratum = FIRST(stratum) /totexp = SUM(totexp) /populat = SUM(populat) 
  /exp_item = SUM(exp_item) /quan_day = FIRST(quan_day)
  /std_code = FIRST(std_code).

* For rural.
* ---------.
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Food expenditure by'+
 ' item.SAV'.
SORT CASES BY
  stratum (A) dzongkha (A) town (A) block (A) houseno (A) itemcode (A) .
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\poor40.sav'
 /RENAME (exp_annu npc_cons pc_cons rpc_cons weight = d0 d1 d2 d3 d4 )
 /BY stratum dzongkha town block houseno
 /DROP= d0 d1 d2 d3 d4 .
EXECUTE.
* Select only poorest 40 percent.
FILTER OFF.
USE ALL.
SELECT IF(popweigh>0).
EXECUTE .
* Compute expenditure per capita on each food item to establish consumption basket.
WEIGHT
  BY weight .
USE ALL.
COMPUTE filter_$=(stratum=2).
FILTER BY filter_$.
EXECUTE .
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work/AGGR.SAV'
  /BREAK=itemcode
  /stratum = FIRST(stratum) / totexp = SUM(exp_annu) .
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR1.SAV'
  /BREAK=stratum dzongkha town block houseno
  /weight = FIRST(weight) /hh_size = FIRST(hh_size).
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR1.SAV'.
WEIGHT
  BY weight .
COMPUTE cntry = 1 .
EXECUTE .
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR2.SAV'
  /BREAK=cntry
  /populat = SUM(hh_size).
* Estimate the quantity by dividing expenditure by median unit prices at stratum level.
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR.sav'.
COMPUTE cntry = 1 .
EXECUTE .
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR2.SAV'
 /BY cntry.
EXECUTE.
FILTER OFF.
USE ALL.
SELECT IF(itemcode<1899).
EXECUTE .
COMPUTE exp_item = totexp/populat .
EXECUTE .
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\Median Unit Price'+
 ' Stratum.sav'
 /BY stratum itemcode.
EXECUTE.
COMPUTE quant_it = exp_item/med_st .
COMPUTE quan_day = quant_it/365 .
EXECUTE .
* Convert Kg to grams, and L to ml.
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\Standard Codes by'+
 ' Item.sav'
 /BY itemcode.
EXECUTE.
IF (std_code=66 or std_code=99) quan_day = quan_day*1000 .
EXECUTE .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp1a.SAV'
  /COMPRESSED.
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp1a.SAV'.
*ADD FILES /FILE=*
* /FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp2a.SAV'.
*EXECUTE.
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp3a.sav'
  /BREAK=itemcode
  /stratum = FIRST(stratum) /totexp = SUM(totexp) /populat = SUM(populat) 
  /exp_item = SUM(exp_item) /quan_day = FIRST(quan_day)
  /std_code = FIRST(std_code).

* Merge urban and rural, and compute weighted quantities of each item.
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp3.sav'.
RENAME VARIABLES (quan_day=quan_urb) (populat=pop_urb) (totexp=exp_urb)
                 (exp_item=urb_item).
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp3a.SAV'
 /RENAME (std_code stratum = d0 d1)
 /BY itemcode
 /DROP= d0 d1.
EXECUTE.
RENAME VARIABLES (quan_day=quan_rur) (populat=pop_rur) (totexp=exp_rur)
                 (exp_item=rur_item).
COMPUTE wur = pop_urb/(pop_rur+pop_urb) .
COMPUTE wru = pop_rur/(pop_rur+pop_urb) .
EXECUTE .
COMPUTE quant_na = quan_urb*wur+quan_rur*wru .
EXECUTE .
* Do not select alcoholic drinks.
FILTER OFF.
USE ALL.
SELECT IF(itemcode < 1811 or itemcode > 1815).
EXECUTE .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\Food basket'+
 ' poor 40.sav'
  /COMPRESSED.

* Add calories intake by edible share of quantity unit of each item.
IF (itemcode=1111) edible = 1.00  .
IF (itemcode=1111) calori = 3.46  .
IF (itemcode=1112) edible = 1.00  .
IF (itemcode=1112) calori = 3.46  .
IF (itemcode=1113) edible = 1.00  .
IF (itemcode=1113) calori = 3.49  .
IF (itemcode=1114) edible = 1.00  .
IF (itemcode=1114) calori = 3.46  .
IF (itemcode=1119) edible = 1.00  .
IF (itemcode=1119) calori = 3.46  .
IF (itemcode=1120) edible = 1.00  .
IF (itemcode=1120) calori = 3.42  .
IF (itemcode=1131) edible = 1.00  .
IF (itemcode=1131) calori = 3.41  .
*IF (itemcode=1132) edible =   .
*IF (itemcode=1132) calori =   .
*IF (itemcode=1133) edible =   .
*IF (itemcode=1133) calori =   .
*IF (itemcode=1134) edible =   .
*IF (itemcode=1134) calori =   .
*IF (itemcode=1136) edible =   .
*IF (itemcode=1136) calori =   .
*IF (itemcode=1137) edible =   .
*IF (itemcode=1137) calori =   .
IF (itemcode=1140) edible = 1.00  .
IF (itemcode=1140) calori = 3.45  .
IF (itemcode=1211) edible = 1.00  .
IF (itemcode=1211) calori = 0.67  .
*IF (itemcode=1212) edible =   .
*IF (itemcode=1212) calori =   .
IF (itemcode=1215) edible = 1.00  .
IF (itemcode=1215) calori = 4.96  .
*IF (itemcode=1219) edible =   .
*IF (itemcode=1219) calori =   .
IF (itemcode=1222) edible = 1.00  .
IF (itemcode=1222) calori = 7.29  .
*IF (itemcode=1223) edible =   .
*IF (itemcode=1223) calori =   .
*IF (itemcode=1224) edible =   .
*IF (itemcode=1224) calori =   .
*IF (itemcode=1225) edible =   .
*IF (itemcode=1225) calori =   .
IF (itemcode=1300) edible =  1.00 .
IF (itemcode=1300) calori =  75.0 .
IF (itemcode=1410) edible =  0.78 .
IF (itemcode=1410) calori =  0.97 .
IF (itemcode=1420) edible =  1.00 .
IF (itemcode=1420) calori =  2.55 .
*IF (itemcode=1430) edible =   .
*IF (itemcode=1430) calori =   .
IF (itemcode=1511) edible =  1.00 .
IF (itemcode=1511) calori =  1.14 .
IF (itemcode=1512) edible =  1.00 .
IF (itemcode=1512) calori =  1.14 .
IF (itemcode=1513) edible =  1.00 .
IF (itemcode=1513) calori =  1.09 .
IF (itemcode=1514) edible =  1.00 .
IF (itemcode=1514) calori =  1.14 .
IF (itemcode=1515) edible =  1.00 .
IF (itemcode=1515) calori =  1.94 .
IF (itemcode=1521) edible =  1.00 .
IF (itemcode=1521) calori =  2.00 .
*IF (itemcode=1522) edible =   .
*IF (itemcode=1522) calori =   .
*IF (itemcode=1523) edible =   .
*IF (itemcode=1523) calori =   .
IF (itemcode=1611) edible = 0.90  .
IF (itemcode=1611) calori = 0.59  .
IF (itemcode=1612) edible = 0.67  .
IF (itemcode=1612) calori = 0.48  .
IF (itemcode=1613) edible = 0.74  .
IF (itemcode=1613) calori = 0.74  .
IF (itemcode=1614) edible =  0.71 .
IF (itemcode=1614) calori =  1.16 .
*IF (itemcode=1615) edible =   .
*IF (itemcode=1615) calori =   .
*IF (itemcode=1616) edible =   .
*IF (itemcode=1616) calori =   .
*IF (itemcode=1619) edible =   .
*IF (itemcode=1619) calori =   .
IF (itemcode=1621) edible =  1.00 .
IF (itemcode=1621) calori =  1.58 .
IF (itemcode=1622) edible =  0.98 .
IF (itemcode=1622) calori =  0.23 .
*IF (itemcode=1623) edible =   .
*IF (itemcode=1623) calori =   .
*IF (itemcode=1624) edible =   .
*IF (itemcode=1624) calori =   .
*IF (itemcode=1625) edible =   .
*IF (itemcode=1625) calori =   .
IF (itemcode=1626) edible =  0.85 .
IF (itemcode=1626) calori =  0.97 .
IF (itemcode=1627) edible =  0.95 .
IF (itemcode=1627) calori =  0.50 .
*IF (itemcode=1628) edible =   .
*IF (itemcode=1628) calori =   .
*IF (itemcode=1629) edible =   .
*IF (itemcode=1629) calori =   .
IF (itemcode=1630) edible = 0.70  .
IF (itemcode=1630) calori = 0.30  .
*IF (itemcode=1631) edible =   .
*IF (itemcode=1631) calori =   .
*IF (itemcode=1632) edible =   .
*IF (itemcode=1632) calori =   .
*IF (itemcode=1633) edible =   .
*IF (itemcode=1633) calori =   .
*IF (itemcode=1639) edible =   .
*IF (itemcode=1639) calori =   .
IF (itemcode=1711) edible =  1.00 .
IF (itemcode=1711) calori =  0.00 .
IF (itemcode=1712) edible =  1.00 .
IF (itemcode=1712) calori =  0.00 .
*IF (itemcode=1720) edible =   .
*IF (itemcode=1720) calori =   .
IF (itemcode=1731) edible =  1.00 .
IF (itemcode=1731) calori =  9.00 .
*IF (itemcode=1732) edible =   .
*IF (itemcode=1732) calori =   .
*IF (itemcode=1733) edible =   .
*IF (itemcode=1733) calori =   .
IF (itemcode=1734) edible =  1.00 .
IF (itemcode=1734) calori =  9.00 .
IF (itemcode=1735) edible =  1.00 .
IF (itemcode=1735) calori =  9.00 .
*IF (itemcode=1739) edible =   .
*IF (itemcode=1739) calori =   .
IF (itemcode=1741) edible =  1.00 .
IF (itemcode=1741) calori =  0.29 .
*IF (itemcode=1742) edible =   .
*IF (itemcode=1742) calori =   .
*IF (itemcode=1743) edible =   .
*IF (itemcode=1743) calori =   .
*IF (itemcode=1746) edible =   .
*IF (itemcode=1746) calori =   .
*IF (itemcode=1749) edible =   .
*IF (itemcode=1749) calori =   .
IF (itemcode=1750) edible =  1.00 .
IF (itemcode=1750) calori =  0.00 .
IF (itemcode=1760) edible =  1.00 .
IF (itemcode=1760) calori =  3.98 .
*IF (itemcode=1780) edible =   .
*IF (itemcode=1780) calori =   .
*IF (itemcode=1821) edible =   .
*IF (itemcode=1821) calori =   .
*IF (itemcode=1822) edible =   .
*IF (itemcode=1822) calori =   .
*IF (itemcode=1823) edible =   .
*IF (itemcode=1823) calori =   .
EXECUTE.
COMPUTE intake = quant_na*edible*calori .
COMPUTE temp = 1.
EXECUTE .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\Food basket'+
 ' poor 40.sav'
  /COMPRESSED.

AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work/AGGR.SAV'
  /BREAK=temp
  /tot_intk = SUM(intake).
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR.sav'.
COMPUTE multipl = 2124/tot_intk .
EXECUTE .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR.sav'
  /COMPRESSED.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\Food basket poor'+
 ' 40.sav'.
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR.sav'
 /RENAME (tot_intk = d0)
 /BY temp
 /DROP= d0.
EXECUTE.
COMPUTE quan2124 = quant_na*multipl .
EXECUTE .
FILTER OFF.
USE ALL.
SELECT IF(calori>0).
EXECUTE .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\Food basket'+
 ' 2124 Kcal.sav'
  /KEEP itemcode quan2124
  /COMPRESSED.

* Compute the value of the consumption basket at median national prices.
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\Food basket 2124'+
 ' Kcal.sav'.
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\Median Unit Price'+
 ' National.sav'
 /BY itemcode.
EXECUTE.
IF (itemcode<>1300) med_nat = med_nat/1000 .
IF (itemcode<>1300) mean_nat = mean_nat/1000 .
EXECUTE .
COMPUTE costmed = quan2124*med_nat .
COMPUTE costmean = quan2124*mean_nat .
COMPUTE temp=1.
EXECUTE .
TABLES
  /FORMAT BLANK MISSING('.')
  /OBSERVATION= quan2124 costmed costmean
  /GBASE=CASES
  /TABLE=itemcode  BY quan2124 > (STATISTICS) + costmed > (STATISTICS) +
  costmean > (STATISTICS)  .
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp.sav'
  /BREAK=temp
  /costmed 'Cost of food basket based on median prices' = SUM(costmed)
  /costmean 'Cost of food basket based on mean prices' = SUM(costmean).
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp.sav'.
COMPUTE mean_mon = (costmean*365)/12 .
COMPUTE med_mon = (costmed*365)/12 .
EXECUTE .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp.sav'
  /COMPRESSED.
VARIABLE LABELS mean_mon 'Food poverty line (pc/month) based on mean unit prices'
               /med_mon 'Food poverty line (pc/month) based on median unit prices'.
DESCRIPTIVES
  VARIABLES=mean_mon med_mon
  /STATISTICS=MEAN .

* Computation of the non-food component.
* =====================================.

* Compute the share of food in total consumption.
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Consumption by'+
 ' item without imputed State Education.sav'.
RECODE
  itemcode
  (1111 thru 1899=1) (ELSE=0)  INTO  fooditem .
EXECUTE .
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work/AGGR.SAV'
  /BREAK=stratum dzongkha town block houseno fooditem
  /exp = SUM(exp_annu).
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR1.SAV'
  /BREAK=stratum dzongkha town block houseno
  /exptot = SUM(exp_annu).
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR.sav'.
SORT CASES BY
  stratum (A) dzongkha (A) town (A) block (A) houseno (A) .
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR1.SAV'
 /BY stratum dzongkha town block houseno.
EXECUTE.
COMPUTE sharfood = exp/exptot .
EXECUTE .
FILTER OFF.
USE ALL.
SELECT IF(fooditem=1).
EXECUTE .
COMPUTE temp = 1 .
EXECUTE .
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Weight.sav'
 /BY stratum dzongkha town block.
EXECUTE.
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\temp.sav'
 /BY temp.
EXECUTE.
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Paachse Index.sav'
 /RENAME (weight = d0)
 /BY stratum dzongkha town block houseno
 /DROP= d0.
EXECUTE.
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\hhsize.sav'
 /RENAME (weight = d0)
 /BY stratum dzongkha town block houseno
 /DROP= d0.
EXECUTE.
COMPUTE pcexpmon = ((exptot/12)/hh_size)/Paachse .
EXECUTE .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR.sav'
  /COMPRESSED.
WEIGHT
  BY weight .

* Computation of poverty line using food poverty line computed with   .
* mean unit prices.
COMPUTE log_x_z = LN(pcexpmon/mean_mon) .
EXECUTE .
REGRESSION
  /MISSING LISTWISE
  /STATISTICS COEFF OUTS R ANOVA
  /CRITERIA=PIN(.05) POUT(.10)
  /NOORIGIN
  /DEPENDENT sharfood
  /METHOD=ENTER log_x_z  .
* Computation of poverty line using food poverty line computed with   .
* median unit prices.
COMPUTE log_x_z = LN(pcexpmon/med_mon) .
EXECUTE .
REGRESSION
  /MISSING LISTWISE
  /STATISTICS COEFF OUTS R ANOVA
  /CRITERIA=PIN(.05) POUT(.10)
  /NOORIGIN
  /DEPENDENT sharfood
  /METHOD=ENTER log_x_z  .

******************************************************.
* Replace hh size with Nima-s file for consistency.
******************************************************.
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\HH Size Nima.sav'
 /RENAME (popw weight = d0 d1) hh_size=hh_sizen
 /BY stratum dzongkha town block houseno
 /DROP= d0 d1.
EXECUTE.
COMPUTE hh_size = hh_sizen .
EXECUTE .
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR.sav'
  /COMPRESSED.

*************************************************************************************.
*************************************************************************************.
* Compute poverty lines in Excel, using the regression parameters a (constant) and b .
* - Lower poverty line = (2-a)*food poverty line                                     .
* - Upper poverty line = food poverty line / ((a+b)/(1+b))                           . 
*************************************************************************************.
*************************************************************************************.

* Compute incidence of poverty (P0).
COMPUTE upl_mean  = 0.
COMPUTE upl_med  = 0.
COMPUTE lpl_mean  = 0.
COMPUTE lpl_med  = 0.
EXECUTE.
IF (pcexpmon<1030.29)  upl_mean = 1 .
IF (pcexpmon<766.45) upl_med  = 1 .
IF (pcexpmon<732.48) lpl_mean = 1 .
IF (pcexpmon<572.37) lpl_med  = 1 .
EXECUTE .
VARIABLE LABELS upl_mean 'Poverty (upper line, using mean)' 
              / upl_med  'Poverty (upper line, using median)'
              / lpl_mean 'Poverty (lower line, using mean)' 
              / lpl_med  'Poverty (lower line, using median)' .
VALUE LABELS upl_mean  1 'Poor' 
                       0 'Non poor' 
            /upl_med   1 'Poor'  
                       0 'Non poor' 
            /lpl_mean  1 'Poor' 
                       0 'Non poor' 
            /lpl_med   1 'Poor'  
                       0 'Non poor' .
EXECUTE.
COMPUTE popw = weight*hh_size .
EXECUTE .
WEIGHT
  BY popw .
TABLES
  /FORMAT BLANK MISSING('.')
  /GBASE=CASES
  /FTOTAL= $t000004 "Total" $t000002 "Total"
  /TABLE=stratum + $t000004  BY upl_mean + $t000002
  /STATISTICS
  cpct( upl_mean( PCT5.1 ) 'Row %':stratum ).
TABLES
  /FORMAT BLANK MISSING('.')
  /GBASE=CASES
  /FTOTAL= $t000004 "Total" $t000002 "Total"
  /TABLE=stratum + $t000004  BY upl_med + $t000002
  /STATISTICS
  cpct( upl_med( PCT5.1 ) 'Row %':stratum ).
TABLES
  /FORMAT BLANK MISSING('.')
  /GBASE=CASES
  /FTOTAL= $t000001 "Total" $t000002 "Total"
  /TABLE=stratum + $t000001  BY upl_med > (STATISTICS) + $t000002  .
TABLES
  /FORMAT BLANK MISSING('.')
  /GBASE=CASES
  /FTOTAL= $t000004 "Total" $t000002 "Total"
  /TABLE=stratum + $t000004  BY lpl_mean + $t000002
  /STATISTICS
  cpct( lpl_mean( PCT5.1 ) 'Row %':stratum ).
TABLES
  /FORMAT BLANK MISSING('.')
  /GBASE=CASES
  /FTOTAL= $t000004 "Total" $t000002 "Total"
  /TABLE=stratum + $t000004  BY lpl_med + $t000002
  /STATISTICS
  cpct( lpl_med( PCT5.1 ) 'Row %':stratum ).

* Computation of poverty incidence based on different poverty lines.
COMPUTE pov0  = 0.
COMPUTE pov1  = 0.
COMPUTE pov2  = 0.
COMPUTE pov3  = 0.
COMPUTE pov4  = 0.
COMPUTE pov5  = 0.
COMPUTE pov6  = 0.
COMPUTE pov7  = 0.
COMPUTE pov8  = 0.
COMPUTE pov9  = 0.
COMPUTE pov10  = 0.
COMPUTE pov11  = 0.
COMPUTE pov12  = 0.
COMPUTE pov13  = 0.
COMPUTE pov14  = 0.
COMPUTE pov15  = 0.
COMPUTE pov16  = 0.
COMPUTE pov17  = 0.
COMPUTE pov18  = 0.
COMPUTE pov19  = 0.
COMPUTE pov20  = 0.
EXECUTE.
IF (pcexpmon<300)  pov0 = 1 .
IF (pcexpmon<350)  pov1 = 1 .
IF (pcexpmon<400)  pov2 = 1 .
IF (pcexpmon<450)  pov3 = 1 .
IF (pcexpmon<500)  pov4 = 1 .
IF (pcexpmon<550)  pov5 = 1 .
IF (pcexpmon<600)  pov6 = 1 .
IF (pcexpmon<650)  pov7 = 1 .
IF (pcexpmon<700)  pov8 = 1 .
IF (pcexpmon<750)  pov9 = 1 .
IF (pcexpmon<800)  pov10 = 1 .
IF (pcexpmon<850)  pov11 = 1 .
IF (pcexpmon<900)  pov12 = 1 .
IF (pcexpmon<950)  pov13 = 1 .
IF (pcexpmon<1000) pov14 = 1 .
IF (pcexpmon<1050) pov15 = 1 .
IF (pcexpmon<1100) pov16 = 1 .
IF (pcexpmon<1150) pov17 = 1 .
IF (pcexpmon<1200) pov18 = 1 .
IF (pcexpmon<1250) pov19 = 1 .
IF (pcexpmon<1300) pov20 = 1 .
EXECUTE.
VARIABLE LABEL pov0   'Poverty line = 300 Nu' 
              /pov1   'Poverty line = 350 Nu' 
              /pov2   'Poverty line = 400 Nu' 
              /pov3   'Poverty line = 450 Nu' 
              /pov4   'Poverty line = 500 Nu' 
              /pov5   'Poverty line = 550 Nu' 
              /pov6   'Poverty line = 600 Nu' 
              /pov7   'Poverty line = 650 Nu' 
              /pov8   'Poverty line = 700 Nu' 
              /pov9   'Poverty line = 750 Nu' 
              /pov10   'Poverty line = 800 Nu' 
              /pov11   'Poverty line = 850 Nu' 
              /pov12   'Poverty line = 900 Nu' 
              /pov13   'Poverty line = 950 Nu' 
              /pov14  'Poverty line = 1000 Nu' 
              /pov15  'Poverty line = 1050 Nu' 
              /pov16  'Poverty line = 1100 Nu' 
              /pov17  'Poverty line = 1150 Nu' 
              /pov18  'Poverty line = 1200 Nu' 
              /pov19  'Poverty line = 1250 Nu' 
              /pov20  'Poverty line = 1300 Nu' .
VALUE LABELS pov0   1 'Poor' 0 'Non poor' 
            /pov1   1 'Poor' 0 'Non poor' 
            /pov2   1 'Poor' 0 'Non poor' 
            /pov3   1 'Poor' 0 'Non poor' 
            /pov4   1 'Poor' 0 'Non poor' 
            /pov5   1 'Poor' 0 'Non poor' 
            /pov6   1 'Poor' 0 'Non poor' 
            /pov7   1 'Poor' 0 'Non poor' 
            /pov8   1 'Poor' 0 'Non poor' 
            /pov9   1 'Poor' 0 'Non poor' 
            /pov10  1 'Poor' 0 'Non poor' 
            /pov11  1 'Poor' 0 'Non poor' 
            /pov12  1 'Poor' 0 'Non poor' 
            /pov13  1 'Poor' 0 'Non poor' 
            /pov14  1 'Poor' 0 'Non poor' 
            /pov15  1 'Poor' 0 'Non poor' 
            /pov16  1 'Poor' 0 'Non poor' 
            /pov17  1 'Poor' 0 'Non poor' 
            /pov18  1 'Poor' 0 'Non poor' 
            /pov19  1 'Poor' 0 'Non poor' 
            /pov20  1 'Poor' 0 'Non poor' .
TABLES
  /FORMAT BLANK MISSING('.')
  /GBASE=CASES
  /FTOTAL= $t000004 "Total" $t000002 "Total"
  /TABLE=stratum + $t000004  BY pov0 + $t000002
  /STATISTICS
  cpct( pov0( PCT5.1 ) 'Row %':stratum ).
TABLES
  /FORMAT BLANK MISSING('.')
  /GBASE=CASES
  /FTOTAL= $t000004 "Total" $t000002 "Total"
  /TABLE=stratum + $t000004  BY pov1 + $t000002
  /STATISTICS
  cpct( pov1( PCT5.1 ) 'Row %':stratum ).
TABLES
  /FORMAT BLANK MISSING('.')
  /GBASE=CASES
  /FTOTAL= $t000004 "Total" $t000002 "Total"
  /TABLE=stratum + $t000004  BY pov2 + $t000002
  /STATISTICS
  cpct( pov2( PCT5.1 ) 'Row %':stratum ).
TABLES
  /FORMAT BLANK MISSING('.')
  /GBASE=CASES
  /FTOTAL= $t000004 "Total" $t000002 "Total"
  /TABLE=stratum + $t000004  BY pov3 + $t000002
  /STATISTICS
  cpct( pov3( PCT5.1 ) 'Row %':stratum ).
TABLES
  /FORMAT BLANK MISSING('.')
  /GBASE=CASES
  /FTOTAL= $t000004 "Total" $t000002 "Total"
  /TABLE=stratum + $t000004  BY pov4 + $t000002
  /STATISTICS
  cpct( pov4( PCT5.1 ) 'Row %':stratum ).
TABLES
  /FORMAT BLANK MISSING('.')
  /GBASE=CASES
  /FTOTAL= $t000004 "Total" $t000002 "Total"
  /TABLE=stratum + $t000004  BY pov5 + $t000002
  /STATISTICS
  cpct( pov5( PCT5.1 ) 'Row %':stratum ).
TABLES
  /FORMAT BLANK MISSING('.')
  /GBASE=CASES
  /FTOTAL= $t000004 "Total" $t000002 "Total"
  /TABLE=stratum + $t000004  BY pov6 + $t000002
  /STATISTICS
  cpct( pov6( PCT5.1 ) 'Row %':stratum ).
TABLES
  /FORMAT BLANK MISSING('.')
  /GBASE=CASES
  /FTOTAL= $t000004 "Total" $t000002 "Total"
  /TABLE=stratum + $t000004  BY pov7 + $t000002
  /STATISTICS
  cpct( pov7( PCT5.1 ) 'Row %':stratum ).
TABLES
  /FORMAT BLANK MISSING('.')
  /GBASE=CASES
  /FTOTAL= $t000004 "Total" $t000002 "Total"
  /TABLE=stratum + $t000004  BY pov8 + $t000002
  /STATISTICS
  cpct( pov8( PCT5.1 ) 'Row %':stratum ).
TABLES
  /FORMAT BLANK MISSING('.')
  /GBASE=CASES
  /FTOTAL= $t000004 "Total" $t000002 "Total"
  /TABLE=stratum + $t000004  BY pov9 + $t000002
  /STATISTICS
  cpct( pov9( PCT5.1 ) 'Row %':stratum ).
TABLES
  /FORMAT BLANK MISSING('.')
  /GBASE=CASES
  /FTOTAL= $t000004 "Total" $t000002 "Total"
  /TABLE=stratum + $t000004  BY pov10 + $t000002
  /STATISTICS
  cpct( pov10( PCT5.1 ) 'Row %':stratum ).
TABLES
  /FORMAT BLANK MISSING('.')
  /GBASE=CASES
  /FTOTAL= $t000004 "Total" $t000002 "Total"
  /TABLE=stratum + $t000004  BY pov11 + $t000002
  /STATISTICS
  cpct( pov11( PCT5.1 ) 'Row %':stratum ).
TABLES
  /FORMAT BLANK MISSING('.')
  /GBASE=CASES
  /FTOTAL= $t000004 "Total" $t000002 "Total"
  /TABLE=stratum + $t000004  BY pov12 + $t000002
  /STATISTICS
  cpct( pov12( PCT5.1 ) 'Row %':stratum ).
TABLES
  /FORMAT BLANK MISSING('.')
  /GBASE=CASES
  /FTOTAL= $t000004 "Total" $t000002 "Total"
  /TABLE=stratum + $t000004  BY pov13 + $t000002
  /STATISTICS
  cpct( pov13( PCT5.1 ) 'Row %':stratum ).
TABLES
  /FORMAT BLANK MISSING('.')
  /GBASE=CASES
  /FTOTAL= $t000004 "Total" $t000002 "Total"
  /TABLE=stratum + $t000004  BY pov14 + $t000002
  /STATISTICS
  cpct( pov14( PCT5.1 ) 'Row %':stratum ).
TABLES
  /FORMAT BLANK MISSING('.')
  /GBASE=CASES
  /FTOTAL= $t000004 "Total" $t000002 "Total"
  /TABLE=stratum + $t000004  BY pov15 + $t000002
  /STATISTICS
  cpct( pov15( PCT5.1 ) 'Row %':stratum ).
TABLES
  /FORMAT BLANK MISSING('.')
  /GBASE=CASES
  /FTOTAL= $t000004 "Total" $t000002 "Total"
  /TABLE=stratum + $t000004  BY pov16 + $t000002
  /STATISTICS
  cpct( pov16( PCT5.1 ) 'Row %':stratum ).
TABLES
  /FORMAT BLANK MISSING('.')
  /GBASE=CASES
  /FTOTAL= $t000004 "Total" $t000002 "Total"
  /TABLE=stratum + $t000004  BY pov17 + $t000002
  /STATISTICS
  cpct( pov17( PCT5.1 ) 'Row %':stratum ).
TABLES
  /FORMAT BLANK MISSING('.')
  /GBASE=CASES
  /FTOTAL= $t000004 "Total" $t000002 "Total"
  /TABLE=stratum + $t000004  BY pov18 + $t000002
  /STATISTICS
  cpct( pov18( PCT5.1 ) 'Row %':stratum ).
TABLES
  /FORMAT BLANK MISSING('.')
  /GBASE=CASES
  /FTOTAL= $t000004 "Total" $t000002 "Total"
  /TABLE=stratum + $t000004  BY pov19 + $t000002
  /STATISTICS
  cpct( pov19( PCT5.1 ) 'Row %':stratum ).
TABLES
  /FORMAT BLANK MISSING('.')
  /GBASE=CASES
  /FTOTAL= $t000004 "Total" $t000002 "Total"
  /TABLE=stratum + $t000004  BY pov20 + $t000002
  /STATISTICS
  cpct( pov20( PCT5.1 ) 'Row %':stratum ).



* Save a file containing the poverty status of each household.
SAVE OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\HH Poverty'+
 ' Status.sav'
  /KEEP stratum dzongkha town block houseno upl_mean upl_med lpl_mean lpl_med hh_size weight popw
  /COMPRESSED.

* Compute the poverty gap index (P1).
***********************************************************.
***********************************************************.
* Manually edit the poverty line below.
***********************************************************.
***********************************************************.
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR.sav'.
COMPUTE temp = (766.4465-pcexpmon)/766.45 .
COMPUTE temp2 = temp*temp.
COMPUTE temp3 = 1 .
COMPUTE temp4 = 1.
COMPUTE popw = weight*hh_size.
EXECUTE .
IF (temp<0) temp=0.
IF (temp=0) temp2 = 0.
EXECUTE.
WEIGHT
  BY popw .
* At national level.
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work/AGGR1.SAV'
  /BREAK=temp3
  /temp = SUM(temp) /temp2 = SUM(temp2) /pop = SUM(temp4).
* At stratum (urban/rural) level.
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work/AGGR2.SAV'
  /BREAK=stratum
  /temp = SUM(temp) /temp2 = SUM(temp2) /pop = SUM(temp4).

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR1.SAV'.
COMPUTE P1_nat = temp/pop .
COMPUTE P2_nat = temp2/pop .
EXECUTE .
VARIABLE LABELS P1_nat 'Poverty gap index (P1), national'
               /P2_nat 'Poverty severity (P2), national'.
DESCRIPTIVES
  VARIABLES=p1_nat p2_nat
  /STATISTICS=MEAN .

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR2.SAV'.
COMPUTE P1_str = temp/pop .
COMPUTE P2_str = temp2/pop .
EXECUTE .
VARIABLE LABELS P1_str 'Poverty gap index (P1), urban/rural'
               /P2_str 'Poverty severity (P2), urban/rural' .
TABLES
  /FORMAT BLANK MISSING('.')
  /OBSERVATION= p1_str p2_str
  /GBASE=CASES
  /TABLE=stratum  BY p1_str > (STATISTICS) + p2_str > (STATISTICS)  .

* Produce tables on mean per capita consumption by decile and quintile.
* --------------------------------------------------------------------.

* Decile.
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR.sav'.
COMPUTE popw = weight*hh_size.
EXECUTE .
WEIGHT
  BY popw .
RANK
  VARIABLES=pcexpmon  (A) /NTILES (10) /PRINT=NO
  /TIES=MEAN .
RANK
  VARIABLES=pcexpmon  (A) BY stratum  /NTILES (10) /PRINT=NO
  /TIES=MEAN .
TABLES
  /FORMAT BLANK MISSING('.')
  /OBSERVATION= pcexpmon
  /GBASE=CASES
  /FTOTAL= $t000001 "Total"
  /TABLE=npcexpmo + $t000001  BY pcexpmon > (STATISTICS)   /TITLE  'Mean per'+
 ' capita monthly consumption by population decile (national), Nu'.
TABLES
  /FORMAT BLANK MISSING('.')
  /OBSERVATION= pcexpmon
  /GBASE=CASES
  /FTOTAL= $t000002 "Total"
  /TABLE=nti001 + $t000002  BY stratum > (STATISTICS) > pcexpmon >
  (STATISTICS)    /TITLE  'Mean per capita monthly consumption by population'+
 ' decile (urban/rural), Nu'.

* Quintile (national).
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR.sav'.
COMPUTE popw = weight*hh_size.
EXECUTE .
WEIGHT
  BY popw .
RANK
  VARIABLES=pcexpmon  (A) /NTILES (5) /PRINT=NO
  /TIES=MEAN .
RANK
  VARIABLES=pcexpmon  (A) BY stratum  /NTILES (5) /PRINT=NO
  /TIES=MEAN .
TABLES
  /FORMAT BLANK MISSING('.')
  /OBSERVATION= pcexpmon
  /GBASE=CASES
  /FTOTAL= $t000001 "Total"
  /TABLE=npcexpmo + $t000001  BY pcexpmon > (STATISTICS)   /TITLE  'Mean per'+
 ' capita monthly consumption by population quintile (national), Nu'.
* Share of consumption of each quintile in national consumption.
WEIGHT BY
  weight.
TABLES
  /FORMAT BLANK MISSING('.')
  /OBSERVATION= exptot
  /GBASE=CASES
  /FTOTAL= $t000001 "Total"
  /TABLE=npcexpmo + $t000001  BY exptot
  /STATISTICS
  mean( exptot)
  spct( exptot( PCT5.1 ) 'Col Sum %':)
  sum( exptot).

* Quintile (urban).
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR.sav'.
COMPUTE popw = weight*hh_size.
EXECUTE .
USE ALL.
SELECT IF(stratum=1).
EXECUTE .
WEIGHT
  BY popw .
RANK
  VARIABLES=pcexpmon  (A) /NTILES (5) /PRINT=NO
  /TIES=MEAN .
RANK
  VARIABLES=pcexpmon  (A) BY stratum  /NTILES (5) /PRINT=NO
  /TIES=MEAN .
TABLES
  /FORMAT BLANK MISSING('.')
  /OBSERVATION= pcexpmon
  /GBASE=CASES
  /FTOTAL= $t000001 "Total"
  /TABLE=npcexpmo + $t000001  BY pcexpmon > (STATISTICS)   /TITLE  'Mean per'+
 ' capita monthly consumption by population quintile (urban), Nu'.
* Share of consumption of each quintile in urban consumption.
WEIGHT BY
  weight.
TABLES
  /FORMAT BLANK MISSING('.')
  /OBSERVATION= exptot
  /GBASE=CASES
  /FTOTAL= $t000001 "Total"
  /TABLE=npcexpmo + $t000001  BY exptot
  /STATISTICS
  mean( exptot)
  spct( exptot( PCT5.1 ) 'Col Sum %':)
  sum( exptot).

* Quintile (rural).
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR.sav'.
COMPUTE popw = weight*hh_size.
EXECUTE .
USE ALL.
SELECT IF(stratum=2).
EXECUTE .
WEIGHT
  BY popw .
RANK
  VARIABLES=pcexpmon  (A) /NTILES (5) /PRINT=NO
  /TIES=MEAN .
RANK
  VARIABLES=pcexpmon  (A) BY stratum  /NTILES (5) /PRINT=NO
  /TIES=MEAN .
TABLES
  /FORMAT BLANK MISSING('.')
  /OBSERVATION= pcexpmon
  /GBASE=CASES
  /FTOTAL= $t000001 "Total"
  /TABLE=npcexpmo + $t000001  BY pcexpmon > (STATISTICS)   /TITLE  'Mean per'+
 ' capita monthly consumption by population quintile (rural), Nu'.
* Share of consumption of each quintile in rural consumption.
WEIGHT BY
  weight.
TABLES
  /FORMAT BLANK MISSING('.')
  /OBSERVATION= exptot
  /GBASE=CASES
  /FTOTAL= $t000001 "Total"
  /TABLE=npcexpmo + $t000001  BY exptot
  /STATISTICS
  mean( exptot)
  spct( exptot( PCT5.1 ) 'Col Sum %':)
  sum( exptot).



* Lorenz curves.
* -------------.

* National.
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR.sav'.
COMPUTE popw = weight*hh_size.
EXECUTE .
WEIGHT
  BY popw .
RANK
  VARIABLES=pcexpmon  (A) /NTILES (10) /PRINT=NO
  /TIES=MEAN .
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\Lorenz national.sav'
  /BREAK=npcexpmo
  /consump = SUM(pcexpmon).
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\Lorenz national.sav'.
FILTER OFF.
USE ALL.
SELECT IF(npcexpmo>0).
EXECUTE .
IF (npcexpmo=1) cumcons = consump .
IF (npcexpmo>1) cumcons = consump + LAG(consump).
EXECUTE .

* Urban.
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR.sav'.
USE ALL.
COMPUTE filter_$=(stratum=1).
FILTER BY filter_$.
EXECUTE .
COMPUTE popw = weight*hh_size.
EXECUTE .
WEIGHT
  BY popw .
RANK
  VARIABLES=pcexpmon  (A) BY stratum  /NTILES (10) /PRINT=NO
  /TIES=MEAN .
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\Lorenz urban.sav'
  /BREAK=stratum npcexpmo
  /consump = SUM(pcexpmon).
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\Lorenz urban.sav'.
FILTER OFF.
USE ALL.
SELECT IF(npcexpmo>0).
EXECUTE .
IF (npcexpmo=1) cumcons = consump .
IF (npcexpmo>1) cumcons = consump + LAG(consump).
EXECUTE .

* Rural.
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR.sav'.
USE ALL.
COMPUTE filter_$=(stratum=2).
FILTER BY filter_$.
EXECUTE .
COMPUTE popw = weight*hh_size.
EXECUTE .
WEIGHT
  BY popw .
RANK
  VARIABLES=pcexpmon  (A) BY stratum  /NTILES (10) /PRINT=NO
  /TIES=MEAN .
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\Lorenz rural.sav'
  /BREAK=stratum npcexpmo
  /consump = SUM(pcexpmon).
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\Lorenz rural.sav'.
FILTER OFF.
USE ALL.
SELECT IF(npcexpmo>0).
EXECUTE .
IF (npcexpmo=1) cumcons = consump .
IF (npcexpmo>1) cumcons = consump + LAG(consump).
EXECUTE .

* Gini coefficient (using Angus Deaton formula).
* =============================================.

* National.
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR.sav'.
COMPUTE temp1 = 1.
EXECUTE.
COMPUTE popw = weight*hh_size.
EXECUTE .
WEIGHT BY
   popw.
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR3.SAV'
  /BREAK=temp1
  /populat = SUM(temp1) / mpce = MEAN(pcexpmon).
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR.sav'.
COMPUTE temp1 = 1.
EXECUTE.
SORT CASES BY
  pcexpmon (D) .
COMPUTE popw = weight*hh_size.
EXECUTE .
COMPUTE rank = popw.
EXECUTE.
IF (~MISSING(LAG(rank))) rank = LAG(rank) + popw.
EXECUTE.
COMPUTE rank_1st = rank-popw+1.
EXECUTE.
COMPUTE tempn = weight*hh_size*pcexpmon*(rank_1st+(0.5*(hh_size-1))).
EXECUTE.
WEIGHT
  OFF.
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR4.SAV'
  /BREAK=temp1
  /tempn = SUM(tempn).
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR4.SAV'.
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR3.SAV'
 /BY temp1.
EXECUTE.
COMPUTE gini = ((populat+1)/(populat-1)) - ((2/(populat*(populat-1)* mpce)) * tempn) .
EXECUTE .

* Urban.
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR.sav'.
FILTER OFF.
USE ALL.
SELECT IF(stratum=1).
EXECUTE .
COMPUTE temp1 = 1.
EXECUTE.
COMPUTE popw = weight*hh_size.
EXECUTE .
WEIGHT BY
   popw.
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR3.SAV'
  /BREAK=temp1
  /populat = SUM(temp1) / mpce = MEAN(pcexpmon).
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR.sav'.
FILTER OFF.
USE ALL.
SELECT IF(stratum=1).
EXECUTE .
COMPUTE temp1 = 1.
EXECUTE.
SORT CASES BY
  pcexpmon (D) .
COMPUTE popw = weight*hh_size.
EXECUTE .
COMPUTE rank = popw.
EXECUTE.
IF (~MISSING(LAG(rank))) rank = LAG(rank) + popw.
EXECUTE.
COMPUTE rank_1st = rank-popw+1.
EXECUTE.
COMPUTE tempn = weight*hh_size*pcexpmon*(rank_1st+(0.5*(hh_size-1))).
EXECUTE.
WEIGHT
  OFF.
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR4.SAV'
  /BREAK=temp1
  /tempn = SUM(tempn).
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR4.SAV'.
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR3.SAV'
 /BY temp1.
EXECUTE.
COMPUTE gini = ((populat+1)/(populat-1)) - ((2/(populat*(populat-1)* mpce)) * tempn) .
EXECUTE .

* Rural.
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR.sav'.
FILTER OFF.
USE ALL.
SELECT IF(stratum=2).
EXECUTE .
COMPUTE temp1 = 1.
EXECUTE.
COMPUTE popw = weight*hh_size.
EXECUTE .
WEIGHT BY
   popw.
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR3.SAV'
  /BREAK=temp1
  /populat = SUM(temp1) / mpce = MEAN(pcexpmon).
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR.sav'.
FILTER OFF.
USE ALL.
SELECT IF(stratum=2).
EXECUTE .
COMPUTE temp1 = 1.
EXECUTE.
SORT CASES BY
  pcexpmon (D) .
COMPUTE popw = weight*hh_size.
EXECUTE .
COMPUTE rank = popw.
EXECUTE.
IF (~MISSING(LAG(rank))) rank = LAG(rank) + popw.
EXECUTE.
COMPUTE rank_1st = rank-popw+1.
EXECUTE.
COMPUTE tempn = weight*hh_size*pcexpmon*(rank_1st+(0.5*(hh_size-1))).
EXECUTE.
WEIGHT
  OFF.
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR4.SAV'
  /BREAK=temp1
  /tempn = SUM(tempn).
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR4.SAV'.
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR3.SAV'
 /BY temp1.
EXECUTE.
COMPUTE gini = ((populat+1)/(populat-1)) - ((2/(populat*(populat-1)* mpce)) * tempn) .
EXECUTE .

* Computation of Atkinson index with e <> 1.
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR.sav'.
COMPUTE popw = weight*hh_size .
COMPUTE ctry = 1.
EXECUTE .
WEIGHT
  BY popw .
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR1.SAV'
  /BREAK=ctry
  /pcexmean = MEAN(pcexpmon).
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR1.SAV'
 /BY ctry.
EXECUTE.
COMPUTE temp05 = (pcexpmon/pcexmean) ** (1-0.5) .
COMPUTE temp10 = (pcexpmon/pcexmean) ** (1-1) .
COMPUTE temp15 = (pcexpmon/pcexmean) ** (1-1.5) .
COMPUTE temp20 = (pcexpmon/pcexmean) ** (1-2) .
EXECUTE .
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR2.SAV'
  /BREAK=ctry
  /temp05 = SUM(temp05) /temp10 = SUM(temp10) /temp15 = SUM(temp15) /temp20 =
  SUM(temp20) /populat = N(stratum).
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR2.SAV'.
COMPUTE atkin05 = 1 - ((temp05/populat)**(1/(1-0.5))) .
COMPUTE atkin15 = 1 - ((temp15/populat)**(1/(1-1.5)))  .
COMPUTE atkin20 = 1 - ((temp20/populat)**(1/(1-2.0)))  .
EXECUTE .
DESCRIPTIVES
  VARIABLES=atkin05 atkin15 atkin20
  /STATISTICS=MEAN .


* Produce tables that show what percentage of consumption is covered by the items .
* included in the food poverty line basket.

GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Consumption by item.sav'.
FILTER OFF.
USE ALL.
SELECT IF(itemcode<=1780 or itemcode=1899).
EXECUTE .
COMPUTE inbasket = 0.
IF (itemcode=1111) inbasket = 1 .
IF (itemcode=1112) inbasket = 1 .
IF (itemcode=1113) inbasket = 1 .
IF (itemcode=1114) inbasket = 1 .
IF (itemcode=1119) inbasket = 1 .
IF (itemcode=1120) inbasket = 1 .
IF (itemcode=1131) inbasket = 1 .
IF (itemcode=1140) inbasket = 1 .
IF (itemcode=1211) inbasket = 1 .
IF (itemcode=1215) inbasket = 1 .
IF (itemcode=1222) inbasket = 1 .
IF (itemcode=1300) inbasket = 1 .
IF (itemcode=1410) inbasket = 1 .
IF (itemcode=1420) inbasket = 1 .
IF (itemcode=1511) inbasket = 1 .
IF (itemcode=1512) inbasket = 1 .
IF (itemcode=1513) inbasket = 1 .
IF (itemcode=1514) inbasket = 1 .
IF (itemcode=1515) inbasket = 1 .
IF (itemcode=1521) inbasket = 1 .
IF (itemcode=1611) inbasket = 1 .
IF (itemcode=1612) inbasket = 1 .
IF (itemcode=1613) inbasket = 1 .
IF (itemcode=1614) inbasket = 1 .
IF (itemcode=1621) inbasket = 1 .
IF (itemcode=1622) inbasket = 1 .
IF (itemcode=1626) inbasket = 1 .
IF (itemcode=1627) inbasket = 1 .
IF (itemcode=1630) inbasket = 1 .
IF (itemcode=1731) inbasket = 1 .
IF (itemcode=1734) inbasket = 1 .
IF (itemcode=1735) inbasket = 1 .
IF (itemcode=1741) inbasket = 1 .
IF (itemcode=1760) inbasket = 1 .
EXECUTE.
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\poorest40.sav'
 /RENAME (exp_annu hh_size hh_t_mo pc_t_mo pc_texp rpc_texp weight = d0 d1 d2 d3 d4
  d5 d6)
 /BY stratum dzongkha town block houseno
 /DROP= d0 d1 d2 d3 d4 d5 d6.
EXECUTE.
RECODE
  npc_texp  (1=1)  (2=2)  (SYSMIS=0)  (ELSE=0)  .
EXECUTE .
MATCH FILES /FILE=*
 /TABLE='C:\_OD\Databank\Bhutan\BLSS 2003\Data\Weight.sav'
 /BY stratum dzongkha town block.
EXECUTE.
WEIGHT
  BY weight .
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work/AGGR.SAV'
  /BREAK=inbasket
  /exp_annu = SUM(exp_annu).
USE ALL.
COMPUTE filter_$=(npc_texp=1).
FILTER BY filter_$.
EXECUTE .
AGGREGATE
  /OUTFILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR1.SAV'
  /BREAK=inbasket
  /exp_annu = SUM(exp_annu).
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR.sav'.
TABLES
  /FORMAT BLANK MISSING('.')
  /OBSERVATION= exp_annu
  /GBASE=CASES
  /FTOTAL= $t000001 "Total"
  /TABLE=inbasket + $t000001  BY exp_annu
  /TITLE 'Food basket items as % of total food consumption' 
  /STATISTICS
  spct( exp_annu( PCT5.1 ) 'Col Sum %':).
GET
  FILE='C:\_OD\Databank\Bhutan\BLSS 2003\Work\AGGR1.sav'.
TABLES
  /FORMAT BLANK MISSING('.')
  /OBSERVATION= exp_annu
  /GBASE=CASES
  /FTOTAL= $t000001 "Total"
  /TABLE=inbasket + $t000001  BY exp_annu
  /TITLE 'Food basket items as % of food consumption of poorest 40%' 
  /STATISTICS
  spct( exp_annu( PCT5.1 ) 'Col Sum %':).


















